MICROBIOLOGY = [
    'actinobacteria',
    'adenovirus',
    'aerobe',
    'almeida',
    'anabiosis',
    'anaerobe',
    'antibiotics',
    'antigen',
    'antiseptics',
    'archeon',
    'bacillus',
    'bacteria',
    'bacteriophage',
    'bacterium',
    'baltimore',
    'beijerinck',
    'biofilm',
    'bioluminescence',
    'bioterrorism',
    'blumberg',
    'capsid',
    'capsomer',
    'capsomere',
    'capsule',
    'chickenpox',
    'coinfection',
    'coronavirus',
    'ebola',
    'endolysin',
    'endotoxin',
    'enterobacterales',
    'enterotoxin',
    'epidemiologist',
    'escherichia',
    'exotoxin',
    'fermentation',
    'flagellum',
    'fleming',
    'gallo',
    'gene',
    'genomes',
    'geomicrobiology',
    'herpesvirus',
    'hiv',
    'hosts',
    'immunity',
    'infection',
    'influenza',
    'ivanovsky',
    'koch',
    'lactobacillus',
    'leeuwenhoek',
    'loeffler',
    'lysin',
    'lysis',
    'mayer',
    'metagenome',
    'microbe',
    'microbiologist',
    'microbiology',
    'microbiome',
    'microbiota',
    'microorganism',
    'monod',
    'montagnier',
    'mutation',
    'mycovirus',
    'nucleocapsid',
    'oncovirus',
    'papillomavirus',
    'pasteur',
    'pathogen',
    'pathogenesis',
    'phage',
    'phagetherapy',
    'polymerases',
    'prophage',
    'protease',
    'proteins',
    'provirus',
    'receptor',
    'retrovirus',
    'rotavirus',
    'salk',
    'sarscov2',
    'serology',
    'spike',
    'stanley',
    'staphylococcus',
    'strains',
    'theiler',
    'transmission',
    'variant',
    'virion',
    'viroid',
    'virologist',
    'virome',
    'virulence',
    'viruses',
    'zikavirus',
    'zoonosis',

]



COUNTRIES = [
    'afghanistan',
    'albania',
    'algeria',
    'andorra',
    'angola',
    'argentina',
    'armenia',
    'aruba',
    'australia',
    'austria',
    'azerbaijan',
    'bahamas',
    'bahrain',
    'bangladesh',
    'barbados',
    'belarus',
    'belgium',
    'belize',
    'benin',
    'bhutan',
    'bolivia',
    'botswana',
    'brazil',
    'brunei',
    'bulgaria',
    'burkina',
    'burundi',
    'cambodia',
    'cameroon',
    'canada',
    'capeverde',
    'chad',
    'chile',
    'china',
    'colombia',
    'comoros',
    'congo',
    'costarica',
    'croatia',
    'cuba',
    'curaco',
    'cyprus',
    'czechrepublic',
    'denmark',
    'djibouti',
    'dominica',
    'ecuador',
    'egypt',
    'elsalvador',
    'eritrea',
    'estonia',
    'eswatini',
    'ethiopia',
    'fiji',
    'finland',
    'france',
    'gabon',
    'gambia',
    'georgia',
    'germany',
    'ghana',
    'greece',
    'grenada',
    'guatemala',
    'guinea',
    'guineabissau',
    'guyana',
    'haiti',
    'honduras',
    'hungary',
    'iceland',
    'india',
    'indonesia',
    'iran',
    'iraq',
    'ireland',
    'israel',
    'italy',
    'ivorycoast',
    'jamaica',
    'japan',
    'jordan',
    'kazakhstan',
    'kenya',
    'kiribati',
    'kosovo',
    'kuwait',
    'kyrgyzstan',
    'laos',
    'latvia',
    'lebanon',
    'lesotho',
    'liberia',
    'libya',
    'liechtenstein',
    'lithuania',
    'luxembourg',
    'macedonia',
    'madagascar',
    'malawi',
    'malaysia',
    'maldives',
    'mali',
    'malta',
    'mauritania',
    'mauritius',
    'mexico',
    'micronesia',
    'moldova',
    'monaco',
    'mongolia',
    'montenegro',
    'morocco',
    'mozambique',
    'myanmar',
    'namibia',
    'nauru',
    'nepal',
    'netherlands',
    'newzealand',
    'nicaragua',
    'niger',
    'nigeria',
    'northkorea',
    'norway',
    'oman',
    'pakistan',
    'palau',
    'palestine',
    'panama',
    'paraguay',
    'peru',
    'philippines',
    'poland',
    'portugal',
    'qatar',
    'romania',
    'russia',
    'rwanda',
    'samoa',
    'saudiarabia',
    'senegal',
    'serbia',
    'seychelles',
    'sierraleone',
    'singapore',
    'slovakia',
    'slovenia',
    'solomonislands',
    'somalia',
    'southkorea',
    'spain',
    'srilanka',
    'sudan',
    'suriname',
    'sweden',
    'switzerland',
    'syria',
    'taiwan',
    'tajikistan',
    'tanzania',
    'thailand',
    'togo',
    'tonga',
    'tunisia',
    'turkey',
    'turkmenistan',
    'tuvalu',
    'uganda',
    'ukraine',
    'unitedkingdom',
    'unitedstates',
    'uruguay',
    'usa',
    'uzbekistan',
    'vanuatu',
    'vatican',
    'venezuela',
    'vietnam',
    'yemen',
    'zambia',
    'zimbabwe',

]



CHEMISTRY = [
    'acid',
    'alkane',
    'alkene',
    'alkyne',
    'amide',
    'amine',
    'anion',
    'anode',
    'atoms',
    'autoionization',
    'avogadro',
    'barometer',
    'beaker',
    'bond',
    'calorie',
    'calorimeter',
    'calorimetry',
    'capillary',
    'carbanion',
    'carbon',
    'catalyst',
    'cathode',
    'charge',
    'chemical',
    'chemist',
    'chromatography',
    'colloid',
    'combustion',
    'compound',
    'concentration',
    'condensation',
    'conformations',
    'crystal',
    'curie',
    'decay',
    'decomposition',
    'detergent',
    'deuterium',
    'diffusions',
    'dilution',
    'dimer',
    'dipole',
    'dissociation',
    'distillation',
    'donor',
    'dosimeter',
    'effusion',
    'electrode',
    'electrolysis',
    'electrolyte',
    'electrons',
    'electrophile',
    'electrophoresis',
    'element',
    'emulsion',
    'enthalpy',
    'entropy',
    'equilibrium',
    'ester',
    'ether',
    'evaporization',
    'fission',
    'frequency',
    'gas',
    'gel',
    'halogen',
    'heat',
    'hydrate',
    'hydration',
    'hydrocarbon',
    'hydrolysis',
    'ion',
    'isotope',
    'kelvin',
    'ketone',
    'liquid',
    'mass',
    'mendeleev',
    'metalloids',
    'mixture',
    'molality',
    'molarity',
    'molecule',
    'moles',
    'neutralization',
    'neutrons',
    'nitrogen',
    'nucleon',
    'octet',
    'osmosis',
    'oxidation',
    'oxide',
    'particles',
    'pauling',
    'periodicity',
    'periods',
    'peroxide',
    'phase',
    'phenol',
    'pipette',
    'plasma',
    'polymer',
    'polymerization',
    'product',
    'protons',
    'raoult',
    'reactant',
    'reaction',
    'redox',
    'rutherford',
    'salt',
    'saponification',
    'silicones',
    'solute',
    'solution',
    'solvent',
    'stereoisomers',
    'stoichiometry',
    'sublimation',
    'substance',
    'temperature',
    'term',
    'thermodynamics',
    'vapor',
    'vaporization',
    'volatile',
    'volume',

]



MUSIC = [
    'acappella',
    'accelerando',
    'adagio',
    'allegro',
    'alto',
    'andante',
    'aria',
    'arrangement',
    'audio',
    'bach',
    'balla',
    'ballet',
    'band',
    'banjo',
    'baritone',
    'bass',
    'bassoon',
    'beat',
    'beethoven',
    'bell',
    'blues',
    'bobdylan',
    'bobmarley',
    'bolero',
    'bongo',
    'brahms',
    'bryanadams',
    'bugle',
    'cadence',
    'canon',
    'cantata',
    'carlossantana',
    'celesta',
    'cello',
    'chant',
    'chimes',
    'chopin',
    'chorale',
    'chord',
    'chorus',
    'clarinet',
    'clef',
    'composer',
    'concerto',
    'contrabassoon',
    'contralto',
    'cornet',
    'cymbal',
    'cymbals',
    'czajkowski',
    'deanmartin',
    'diminution',
    'downbeat',
    'drum',
    'duet',
    'duple',
    'eltonjohn',
    'elvispresley',
    'eminem',
    'ensemble',
    'etude',
    'expressionism',
    'falsetto',
    'flute',
    'forte',
    'fortepiano',
    'fortissimo',
    'freddiemercury',
    'fugue',
    'gamelan',
    'georgemichael',
    'gong',
    'guitar',
    'habanera',
    'harmony',
    'harp',
    'harpsichord',
    'hiphop',
    'horn',
    'improvisation',
    'interval',
    'intro',
    'jimihendrix',
    'kettledrums',
    'key',
    'koto',
    'largo',
    'legato',
    'libretto',
    'lionelrichie',
    'lute',
    'madrigal',
    'marimba',
    'mazurka',
    'melody',
    'metallica',
    'mezzoforte',
    'mezzopiano',
    'michaeljackson',
    'minuet',
    'moderato',
    'modulation',
    'mozart',
    'mp3',
    'music',
    'mute',
    'nocturne',
    'notation',
    'note',
    'oboe',
    'octave',
    'opera',
    'orchestra',
    'overture',
    'philcollins',
    'pianissimo',
    'piano',
    'pianoforte',
    'piccolo',
    'pinkfloyd',
    'pitch',
    'polka',
    'polonaise',
    'polyphony',
    'prelude',
    'presto',
    'quartet',
    'quintet',
    'raga',
    'ragtime',
    'rap',
    'raycharles',
    'recital',
    'recorder',
    'recording',
    'refrain',
    'rehearsal',
    'requiem',
    'rhythm',
    'ritardando',
    'rock',
    'rodstewart',
    'rollingstones',
    'royorbison',
    'rubato',
    'sax',
    'saxophone',
    'schumann',
    'serenade',
    'shakuhachi',
    'snare',
    'sonata',
    'song',
    'soprano',
    'sousaphone',
    'steviewonder',
    'strauss',
    'string',
    'swing',
    'synthesizer',
    'tambourine',
    'tempo',
    'tenor',
    'thebeatles',
    'theme',
    'timpani',
    'tinaturner',
    'tone',
    'triplet',
    'trombone',
    'trumpet',
    'tuba',
    'tuning',
    'tupac',
    'vibes',
    'vibrato',
    'viola',
    'violin',
    'viruoso',
    'wagner',
    'waltz',
    'xylophone',

]



MOLECULAR_BIOLOGY = [
    'adenine',
    'allele',
    'aminoacid',
    'amplicon',
    'antibody',
    'anticodon',
    'biochemistry',
    'bioenergetics',
    'bioinformatics',
    'biotechnology',
    'brenner',
    'cell',
    'centriole',
    'centrosome',
    'chromatid',
    'chromosome',
    'codon',
    'coenzyme',
    'complementation',
    'contig',
    'cosmid',
    'crick',
    'crossingover',
    'deletion',
    'deoxyribose',
    'diploid',
    'dna',
    'dynein',
    'electroporation',
    'endocytosis',
    'endonuclease',
    'enhancer',
    'enzyme',
    'epigenetics',
    'euchromatin',
    'exon',
    'exonuclease',
    'franklin',
    'geneexpression',
    'genes',
    'genome',
    'genomics',
    'haploid',
    'helicase',
    'heterochromatin',
    'heteroduplex',
    'hybridization',
    'hydrophil',
    'hydrophob',
    'immunoglobulin',
    'inhibitor',
    'insertion',
    'intron',
    'junkdna',
    'kimura',
    'kinase',
    'ligase',
    'lipoprotein',
    'loci',
    'luciferase',
    'lysogeny',
    'metabolomics',
    'microbes',
    'monosaccharide',
    'mrna',
    'mutations',
    'myosin',
    'nadp+',
    'nadph',
    'nucleolus',
    'nucleosome',
    'nucleotide',
    'oligonucleotide',
    'operon',
    'orf',
    'peptidoglycan',
    'plasmid',
    'polyadenylation',
    'polymerase',
    'polysaccharide',
    'primer',
    'probe',
    'promoter',
    'protein',
    'proteomics',
    'proteosome',
    'pyrimidine',
    'recombination',
    'replication',
    'restriction',
    'retrotransposon',
    'ribonuclease',
    'ribosome',
    'rna',
    'sequencing',
    'splicing',
    'supercoil',
    'superinfection',
    'taqpolymerase',
    'telomerase',
    'telomere',
    'terminator',
    'thymine',
    'topoisomerase',
    'transcriptase',
    'transcription',
    'transduction',
    'translation',
    'transposon',
    'trna',
    'ubiquitin',
    'uracil',
    'vectors',
    'venter',
    'virology',
    'virusoid',
    'watson',
    'westernblot',

]



GEOGRAPHY = [
    'afforestation',
    'agriculture',
    'alluvium',
    'altitude',
    'anemometer',
    'antarctic',
    'anticyclone',
    'archipelago',
    'atlas',
    'atmosphere',
    'atoll',
    'azimuth',
    'bay',
    'beach',
    'biodiversity',
    'biosphere',
    'border',
    'butte',
    'caldera',
    'canal',
    'canyon',
    'cape',
    'capital',
    'cartogram',
    'cartography',
    'cave',
    'channel',
    'chart',
    'cimate',
    'city',
    'cliff',
    'cloud',
    'compass',
    'continent',
    'contour',
    'coordinates',
    'corrasion',
    'corrosion',
    'country',
    'cove',
    'crust',
    'cumulonimbus',
    'cumulus',
    'cyclone',
    'deflation',
    'degrees',
    'delta',
    'depression',
    'desert',
    'desertification',
    'drainage',
    'drift',
    'drought',
    'dune',
    'earthquake',
    'east',
    'ecosystems',
    'elevation',
    'emigration',
    'environment',
    'equator',
    'erosion',
    'escarpment',
    'estuary',
    'exfoliation',
    'fjord',
    'front',
    'geolocalization',
    'geyser',
    'glaciation',
    'glacier',
    'globalization',
    'globe',
    'gps',
    'granite',
    'groundwater',
    'gulf',
    'habitat',
    'hemisphere',
    'hill',
    'horizon',
    'hurricane',
    'hydrosphere',
    'hygrometer',
    'iceberg',
    'immigration',
    'industrialization',
    'ionospheres',
    'island',
    'isobar',
    'isohyet',
    'isotherm',
    'laccolith',
    'lagoon',
    'lake',
    'land',
    'landform',
    'latitude',
    'lava',
    'legend',
    'limestone',
    'location',
    'longitude',
    'magma',
    'map',
    'marble',
    'marsh',
    'meander',
    'meridian',
    'mesa',
    'moraine',
    'mortlake',
    'mountain',
    'nation',
    'north',
    'oasis',
    'ocean',
    'ozone',
    'pangaea',
    'parallel',
    'passage',
    'peak',
    'peninsula',
    'permafrost',
    'plain',
    'plateau',
    'pole',
    'pollution',
    'pond',
    'population',
    'pothole',
    'prairie',
    'pyroclasts',
    'quartz',
    'rain',
    'reef',
    'region',
    'reservoir',
    'resource',
    'river',
    'rocks',
    'savanna',
    'scale',
    'sea',
    'sediment',
    'seismograph',
    'seismology',
    'sill',
    'smog',
    'soil',
    'solifluction',
    'sound',
    'source',
    'south',
    'spring',
    'stalactite',
    'stalagmite',
    'strait',
    'strata',
    'stratosphere',
    'stratus',
    'swamp',
    'swash',
    'taiga',
    'terracing',
    'territory',
    'tides',
    'topography',
    'tornado',
    'tributary',
    'tropics',
    'tsunami',
    'tundra',
    'typhoon',
    'urbanization',
    'valley',
    'volcano',
    'waterfall',
    'waves',
    'weather',
    'west',
    'wetland',
    'world',

]



ADJECTIVES = [
    'abandoned',
    'abashed',
    'aberrant',
    'abhorrent',
    'abiding',
    'abject',
    'ablaze',
    'able',
    'abounding',
    'abrasive',
    'abrupt',
    'absent',
    'absolute',
    'absorbed',
    'absorbing',
    'abstract',
    'abstracted',
    'absurd',
    'abundant',
    'academic',
    'acceptable',
    'accepted',
    'accepting',
    'accessible',
    'accidental',
    'accurate',
    'accused',
    'ace',
    'achromatic',
    'acidic',
    'acoustic',
    'acrid',
    'actionable',
    'active',
    'actual',
    'acute',
    'acyclic',
    'adamant',
    'adaptable',
    'adapting',
    'adaptive',
    'added',
    'additional',
    'adept',
    'adequate',
    'adhesive',
    'adiabatic',
    'adjacent',
    'adjoining',
    'adjusted',
    'administrative',
    'admiring',
    'adorable',
    'adoring',
    'adroit',
    'advanced',
    'adventurous',
    'adverse',
    'advisory',
    'aesthetic',
    'affable',
    'affectionate',
    'afraid',
    'aged',
    'aggregate',
    'aggressive',
    'agile',
    'agitated',
    'agonizing',
    'agreeable',
    'agreed',
    'agricultural',
    'airy',
    'alert',
    'alive',
    'all',
    'alleged',
    'allegro',
    'allied',
    'allowing',
    'alluring',
    'alone',
    'aloof',
    'alright',
    'alternate',
    'alternating',
    'alternative',
    'amateur',
    'amazed',
    'amazing',
    'amber',
    'ambiguous',
    'ambitious',
    'amiable',
    'amicable',
    'amortized',
    'ample',
    'amused',
    'amusing',
    'ancient',
    'andante',
    'angry',
    'animated',
    'animato',
    'annoyed',
    'annoying',
    'annual',
    'anonymous',
    'another',
    'antique',
    'anxious',
    'apathetic',
    'appalling',
    'apparent',
    'applicable',
    'appropriate',
    'approximate',
    'aquamarine',
    'aquatic',
    'arbitrary',
    'archaic',
    'architectural',
    'arctic',
    'ardent',
    'arid',
    'armed',
    'aromatic',
    'arriving',
    'arrogant',
    'artificial',
    'artistic',
    'ascent',
    'ashamed',
    'asleep',
    'asphalt',
    'aspiring',
    'assistant',
    'associated',
    'associative',
    'assorted',
    'assured',
    'assuring',
    'astonishing',
    'astute',
    'asymptotic',
    'atomic',
    'attractive',
    'auburn',
    'augmenting',
    'august',
    'auspicious',
    'automatic',
    'autonomous',
    'available',
    'average',
    'avid',
    'avocado',
    'awaited',
    'awake',
    'aware',
    'awesome',
    'awful',
    'awkward',
    'axiomatic',
    'azure',
    'back',
    'backstabbing',
    'bad',
    'baked',
    'balanced',
    'balmy',
    'barbarous',
    'bare',
    'bashful',
    'basic',
    'bawdy',
    'beautiful',
    'becoming',
    'befitting',
    'beige',
    'belligerent',
    'beloved',
    'beneficial',
    'benevolent',
    'bent',
    'berserk',
    'best',
    'better',
    'beveled',
    'bewildered',
    'big',
    'billowing',
    'billowy',
    'binary',
    'binding',
    'biological',
    'bipartite',
    'bisque',
    'bitter',
    'bizarre',
    'bizzare',
    'black',
    'bland',
    'blank',
    'blaring',
    'blazing',
    'blended',
    'blessed',
    'blind',
    'blistering',
    'blocking',
    'blocky',
    'blonde',
    'bloody',
    'blue',
    'blushing',
    'boiling',
    'bold',
    'bone',
    'boolean',
    'booming',
    'boorish',
    'bordeaux',
    'bored',
    'boring',
    'bossy',
    'bottom',
    'bouncy',
    'bounded',
    'boundless',
    'boxy',
    'brainy',
    'braised',
    'brash',
    'brass',
    'brave',
    'brawny',
    'breakable',
    'breezy',
    'brief',
    'bright',
    'brilliant',
    'briny',
    'brisk',
    'broad',
    'broken',
    'bronze',
    'brown',
    'brownian',
    'brutal',
    'bruteforce',
    'bumpy',
    'buoyant',
    'burgundy',
    'burly',
    'burning',
    'bursting',
    'bustling',
    'busy',
    'buttery',
    'cagey',
    'calculating',
    'callous',
    'calm',
    'camel',
    'can',
    'canary',
    'candied',
    'canny',
    'capable',
    'capital',
    'capitalist',
    'capricious',
    'caramel',
    'caramelized',
    'cared',
    'careful',
    'careless',
    'caring',
    'casual',
    'causal',
    'cautious',
    'ceaseless',
    'celeste',
    'celestial',
    'central',
    'certain',
    'cerulean',
    'chalky',
    'chamfered',
    'champagne',
    'champion',
    'changeable',
    'changing',
    'chaotic',
    'characteristic',
    'charcoal',
    'charitable',
    'charmed',
    'charming',
    'chartreuse',
    'cheap',
    'cheeky',
    'cheerful',
    'cheesy',
    'chemical',
    'chestnut',
    'chewy',
    'chic',
    'chief',
    'childlike',
    'chill',
    'chilly',
    'chivalrous',
    'chocolate',
    'chocolaty',
    'choice',
    'chosen',
    'christian',
    'chromatic',
    'chronic',
    'chubby',
    'chummy',
    'chunky',
    'circular',
    'citric',
    'citron',
    'civic',
    'civil',
    'civilian',
    'clammy',
    'claret',
    'classic',
    'classical',
    'classy',
    'clean',
    'clear',
    'clever',
    'climbing',
    'clinical',
    'cloistered',
    'close',
    'closed',
    'closing',
    'cloudy',
    'cloying',
    'clumsy',
    'cluttered',
    'coal',
    'coastal',
    'cobalt',
    'coffee',
    'cogent',
    'cognitive',
    'coherent',
    'coincident',
    'cold',
    'collective',
    'collinear',
    'colonial',
    'colorful',
    'colossal',
    'coloured',
    'colourful',
    'combative',
    'combined',
    'comfortable',
    'comic',
    'coming',
    'commercial',
    'common',
    'communal',
    'communist',
    'commutative',
    'compact',
    'comparable',
    'comparative',
    'compassionate',
    'compatible',
    'competent',
    'competitive',
    'complete',
    'complex',
    'complicated',
    'composed',
    'composite',
    'comprehensive',
    'compulsory',
    'concave',
    'concentric',
    'conceptual',
    'concerned',
    'concise',
    'concrete',
    'concurrent',
    'condemned',
    'condescending',
    'confident',
    'confidential',
    'confused',
    'congruent',
    'connected',
    'conscious',
    'conservation',
    'conservative',
    'considerable',
    'consistent',
    'constant',
    'constitutional',
    'contemporary',
    'content',
    'continental',
    'continued',
    'continuing',
    'continuous',
    'controlled',
    'controversial',
    'convenient',
    'conventional',
    'convex',
    'convinced',
    'convincing',
    'convoluted',
    'cooing',
    'cool',
    'cooperative',
    'coordinated',
    'coped',
    'coplanar',
    'coral',
    'corn',
    'corporate',
    'correct',
    'corresponding',
    'cosmic',
    'costly',
    'counting',
    'courageous',
    'courtly',
    'covering',
    'cowardly',
    'cozy',
    'crabby',
    'crack',
    'cranky',
    'craven',
    'crazy',
    'cream',
    'creamy',
    'creative',
    'credible',
    'creepy',
    'criminal',
    'crimson',
    'crispy',
    'critical',
    'crooked',
    'cross',
    'crowded',
    'crucial',
    'crude',
    'cruel',
    'crunchy',
    'cuddly',
    'cultural',
    'cultured',
    'cumbersome',
    'cunning',
    'curious',
    'curly',
    'current',
    'curved',
    'curvy',
    'cute',
    'cyan',
    'cyclic',
    'cynical',
    'daffy',
    'daily',
    'dainty',
    'damaged',
    'damaging',
    'damp',
    'dandy',
    'dangerous',
    'dapper',
    'daring',
    'dark',
    'dashing',
    'dazzling',
    'dead',
    'deadly',
    'deadpan',
    'deaf',
    'deafening',
    'dear',
    'debonair',
    'decent',
    'decidable',
    'deciding',
    'decisive',
    'decorous',
    'deep',
    'deeply',
    'defeated',
    'defective',
    'defensive',
    'defiant',
    'definite',
    'deft',
    'deliberate',
    'delicate',
    'delicious',
    'delighted',
    'delightful',
    'delirious',
    'deluxe',
    'democratic',
    'demonic',
    'denim',
    'dense',
    'dependent',
    'depressed',
    'deranged',
    'descent',
    'descriptive',
    'desert',
    'deserted',
    'desirable',
    'desired',
    'desperate',
    'destined',
    'detailed',
    'determined',
    'deterministic',
    'developed',
    'developing',
    'devilish',
    'devoted',
    'devout',
    'diachronic',
    'diagonal',
    'dichotomic',
    'didactic',
    'different',
    'difficult',
    'digital',
    'diligent',
    'diplomatic',
    'direct',
    'direful',
    'dirty',
    'disabled',
    'disagreeable',
    'disappointed',
    'disastrous',
    'disciplinary',
    'discreet',
    'discrete',
    'disgusted',
    'disgusting',
    'disillusioned',
    'dispensable',
    'distant',
    'distinct',
    'distinctive',
    'distinguished',
    'distracted',
    'distraught',
    'district',
    'disturbed',
    'disturbing',
    'divergent',
    'diverse',
    'divine',
    'dizzy',
    'domestic',
    'dominant',
    'domineering',
    'doted',
    'doting',
    'double',
    'doubtful',
    'doughy',
    'drab',
    'draconian',
    'dramatic',
    'dreadful',
    'dreamy',
    'dreary',
    'driven',
    'driving',
    'drunk',
    'dry',
    'dual',
    'dull',
    'dusty',
    'dutch',
    'dyadic',
    'dying',
    'dynamic',
    'dysfunctional',
    'each',
    'eager',
    'early',
    'earsplitting',
    'earthy',
    'eastern',
    'easy',
    'eatable',
    'ebony',
    'economic',
    'ecru',
    'ecstatic',
    'edible',
    'educated',
    'educational',
    'eerie',
    'effective',
    'efficacious',
    'efficient',
    'eight',
    'elaborate',
    'elastic',
    'elated',
    'elderly',
    'eldest',
    'electoral',
    'electric',
    'electrical',
    'electronic',
    'elegant',
    'elfin',
    'eligible',
    'elite',
    'embarrassed',
    'embarrassing',
    'emerald',
    'emerging',
    'eminent',
    'emotional',
    'empirical',
    'empty',
    'enabled',
    'enchanted',
    'enchanting',
    'encouraging',
    'endless',
    'endothermic',
    'endurable',
    'energetic',
    'energized',
    'engaged',
    'engaging',
    'enhanced',
    'enigmatic',
    'enjoyed',
    'enormous',
    'enough',
    'entertaining',
    'enthusiastic',
    'entire',
    'entitled',
    'envious',
    'environmental',
    'epic',
    'equable',
    'equal',
    'equidistant',
    'equilateral',
    'equipped',
    'equivalent',
    'erect',
    'erratic',
    'espressivo',
    'essential',
    'established',
    'estimated',
    'eternal',
    'ethereal',
    'ethical',
    'ethnic',
    'evanescent',
    'evasive',
    'even',
    'eventual',
    'every',
    'everyday',
    'evident',
    'evil',
    'evolutionary',
    'evolved',
    'evolving',
    'exact',
    'excellent',
    'exceptional',
    'excess',
    'excessive',
    'excited',
    'exciting',
    'exclusive',
    'exhaustive',
    'existing',
    'exothermic',
    'exotic',
    'expected',
    'expensive',
    'experienced',
    'experimental',
    'expert',
    'explicit',
    'exponential',
    'express',
    'extended',
    'extensive',
    'external',
    'extra',
    'extraordinary',
    'extravagant',
    'extremal',
    'extreme',
    'exuberant',
    'exultant',
    'fabulous',
    'factorial',
    'factual',
    'faded',
    'faint',
    'fair',
    'faithful',
    'fallacious',
    'false',
    'famed',
    'familiar',
    'famous',
    'fanatical',
    'fancy',
    'fantastic',
    'fascinated',
    'fascinating',
    'fashionable',
    'fast',
    'fat',
    'fatal',
    'faulty',
    'favourable',
    'favourite',
    'fearful',
    'fearless',
    'feasible',
    'federal',
    'feigned',
    'feldspar',
    'fellow',
    'fermented',
    'ferocious',
    'fertile',
    'fervent',
    'festering',
    'festive',
    'fierce',
    'fiery',
    'figurative',
    'filthy',
    'final',
    'financial',
    'fine',
    'finicky',
    'finite',
    'firm',
    'first',
    'fiscal',
    'fit',
    'fitting',
    'fixed',
    'flagrant',
    'flaky',
    'flashed',
    'flashy',
    'flat',
    'flavorful',
    'flawless',
    'fleet',
    'flexible',
    'flimsy',
    'flippant',
    'flowery',
    'flowing',
    'fluent',
    'fluffy',
    'flush',
    'fluttering',
    'flying',
    'foamy',
    'focused',
    'foggy',
    'following',
    'fond',
    'foolish',
    'foregoing',
    'foreign',
    'forgetful',
    'forgiving',
    'forlorn',
    'formal',
    'formidable',
    'forthcoming',
    'fortunate',
    'forward',
    'fragile',
    'frail',
    'frank',
    'frantic',
    'frayed',
    'free',
    'freezing',
    'frequent',
    'fresh',
    'fretful',
    'fried',
    'friendly',
    'frightened',
    'frightening',
    'frigid',
    'front',
    'frosty',
    'frozen',
    'fuchsia',
    'full',
    'fumbling',
    'fun',
    'functional',
    'fundamental',
    'funky',
    'funny',
    'furious',
    'furry',
    'furtive',
    'fuscia',
    'future',
    'futuristic',
    'fuzzy',
    'gabby',
    'gainful',
    'gamy',
    'gaping',
    'garrulous',
    'gastric',
    'gaudy',
    'general',
    'generative',
    'generous',
    'genetic',
    'genial',
    'genteel',
    'gentle',
    'genuine',
    'geographical',
    'giant',
    'giddy',
    'gifted',
    'gigantic',
    'gilded',
    'given',
    'giving',
    'glad',
    'glamorous',
    'glass',
    'gleaming',
    'glib',
    'glistening',
    'global',
    'gloomy',
    'glorious',
    'glossy',
    'glowing',
    'glum',
    'gnarly',
    'godly',
    'gold',
    'golden',
    'good',
    'goodly',
    'goofy',
    'gorgeous',
    'gothic',
    'gourmet',
    'governing',
    'graceful',
    'gradual',
    'grand',
    'grandiose',
    'grandioso',
    'grateful',
    'grating',
    'gratis',
    'grave',
    'gravitational',
    'gray',
    'greasy',
    'great',
    'greedy',
    'green',
    'grey',
    'grieving',
    'grilled',
    'grim',
    'gritty',
    'grizzled',
    'groovy',
    'gross',
    'grotesque',
    'grouchy',
    'growing',
    'grown',
    'grubby',
    'gruesome',
    'grumpy',
    'guarded',
    'guided',
    'guiding',
    'guiltless',
    'guilty',
    'gullible',
    'gusty',
    'gutsy',
    'guttural',
    'habitual',
    'half',
    'hallowed',
    'haloed',
    'halting',
    'handicapped',
    'handsome',
    'handsomely',
    'handy',
    'hanging',
    'hapless',
    'happy',
    'hard',
    'hardy',
    'harmless',
    'harmonious',
    'harsh',
    'hasty',
    'heady',
    'healthy',
    'heartbreaking',
    'heartless',
    'hearty',
    'heather',
    'heavenly',
    'heavy',
    'hellish',
    'helped',
    'helpful',
    'helping',
    'helpless',
    'heroic',
    'hesitant',
    'hidden',
    'hideous',
    'high',
    'highfalutin',
    'hilarious',
    'hip',
    'hissing',
    'historic',
    'historical',
    'hoary',
    'holistic',
    'hollow',
    'holy',
    'homeless',
    'homely',
    'honest',
    'honorable',
    'hopeful',
    'horizontal',
    'horrible',
    'hospitable',
    'hostile',
    'hot',
    'huge',
    'hulking',
    'human',
    'humane',
    'humble',
    'humdrum',
    'humid',
    'humongous',
    'humorous',
    'hungry',
    'hunky',
    'hurried',
    'hurt',
    'hushed',
    'husky',
    'hypnotic',
    'hysterical',
    'icky',
    'icy',
    'ideal',
    'identical',
    'ideological',
    'ignorant',
    'ill',
    'illegal',
    'illustrious',
    'imaginary',
    'imaginative',
    'immature',
    'immediate',
    'immense',
    'imminent',
    'immortal',
    'immune',
    'impartial',
    'imperfect',
    'imperial',
    'implicit',
    'impolite',
    'important',
    'imported',
    'impossible',
    'impressed',
    'impressive',
    'improved',
    'impulsive',
    'inadequate',
    'inappropriate',
    'incandescent',
    'inclined',
    'included',
    'inclusive',
    'incompetent',
    'inconclusive',
    'increased',
    'increasing',
    'incredible',
    'independent',
    'indigo',
    'indirect',
    'individual',
    'indulgent',
    'industrial',
    'industrious',
    'inevitable',
    'inexpensive',
    'infallible',
    'infamous',
    'infinite',
    'inflammable',
    'influential',
    'informal',
    'informed',
    'inherent',
    'initial',
    'injured',
    'inland',
    'innate',
    'inner',
    'innocent',
    'innovative',
    'inquisitive',
    'insane',
    'inscribed',
    'insidious',
    'inspired',
    'instant',
    'instinctive',
    'institutional',
    'insufficient',
    'insulated',
    'intact',
    'integral',
    'integrated',
    'intellectual',
    'intelligent',
    'intense',
    'intensive',
    'intent',
    'interested',
    'interesting',
    'intergalactic',
    'interim',
    'interior',
    'intermediate',
    'internal',
    'international',
    'intimate',
    'intractable',
    'intricate',
    'inventive',
    'inverse',
    'inverted',
    'investor',
    'invincible',
    'invisible',
    'inviting',
    'involved',
    'irate',
    'iron',
    'irregular',
    'irrelevant',
    'irreverent',
    'irritating',
    'isobaric',
    'isochoric',
    'isolated',
    'isometric',
    'isomorphic',
    'isothermal',
    'itchy',
    'ivory',
    'jaded',
    'jagged',
    'jazzed',
    'jazzy',
    'jealous',
    'jellied',
    'jittery',
    'joint',
    'jolly',
    'jovial',
    'joyful',
    'joyous',
    'jubilant',
    'judicial',
    'judicious',
    'juicy',
    'jumbled',
    'jumbo',
    'jumpy',
    'junior',
    'just',
    'juvenile',
    'kaput',
    'keen',
    'key',
    'khaki',
    'kickass',
    'kind',
    'kindhearted',
    'kindly',
    'kinetic',
    'kingly',
    'knotty',
    'knowing',
    'knowledgeable',
    'known',
    'knurled',
    'labored',
    'labour',
    'lackadaisical',
    'lacking',
    'lame',
    'lamentable',
    'laminated',
    'languid',
    'large',
    'largo',
    'last',
    'lasting',
    'late',
    'latent',
    'latin',
    'laughable',
    'lavish',
    'lawful',
    'lazy',
    'lead',
    'leading',
    'lean',
    'learning',
    'leather',
    'left',
    'legacy',
    'legal',
    'legible',
    'legislative',
    'legit',
    'legitimate',
    'lengthy',
    'lenient',
    'lesser',
    'lethal',
    'level',
    'lewd',
    'lexical',
    'liable',
    'liberal',
    'libretto',
    'light',
    'likeable',
    'liked',
    'likely',
    'limber',
    'lime',
    'limited',
    'limitless',
    'limping',
    'linear',
    'linguistic',
    'liquid',
    'literary',
    'literate',
    'little',
    'live',
    'lively',
    'livid',
    'living',
    'local',
    'logical',
    'lonely',
    'long',
    'longing',
    'loose',
    'lopsided',
    'loquacious',
    'lost',
    'loud',
    'lousy',
    'loutish',
    'loved',
    'lovely',
    'loving',
    'low',
    'lower',
    'lowly',
    'loyal',
    'lucid',
    'lucky',
    'ludicrous',
    'lumpy',
    'lush',
    'luxuriant',
    'lying',
    'lyrical',
    'lytic',
    'macabre',
    'macho',
    'mad',
    'maddening',
    'madly',
    'magenta',
    'magic',
    'magical',
    'magnetic',
    'magnificent',
    'main',
    'majestic',
    'major',
    'makeshift',
    'male',
    'malicious',
    'mammoth',
    'managerial',
    'managing',
    'maniac',
    'maniacal',
    'manual',
    'marginal',
    'marinated',
    'marine',
    'marked',
    'maroon',
    'married',
    'marvellous',
    'marvelous',
    'marxist',
    'mashed',
    'mass',
    'massive',
    'master',
    'matching',
    'material',
    'materialistic',
    'mathematical',
    'matte',
    'mature',
    'max',
    'maxed',
    'maximum',
    'mean',
    'meaningful',
    'measly',
    'measured',
    'meaty',
    'mechanical',
    'median',
    'medical',
    'medieval',
    'medium',
    'meek',
    'meet',
    'mellow',
    'melodic',
    'melted',
    'mental',
    'merciful',
    'merciless',
    'mere',
    'merry',
    'messy',
    'metal',
    'metallic',
    'metropolitan',
    'mid',
    'middle',
    'mighty',
    'mild',
    'military',
    'milky',
    'mindless',
    'miniature',
    'minimal',
    'minimum',
    'ministerial',
    'minor',
    'mint',
    'minty',
    'mirthful',
    'miscreant',
    'miserable',
    'misleading',
    'missing',
    'misty',
    'mixed',
    'moaning',
    'mobile',
    'model',
    'moderate',
    'moderato',
    'modern',
    'modest',
    'moist',
    'moldy',
    'molecular',
    'molten',
    'momentous',
    'monetary',
    'monthly',
    'moonlit',
    'moral',
    'motionless',
    'mountainous',
    'moved',
    'moving',
    'mucho',
    'muddled',
    'muddy',
    'muffled',
    'multiple',
    'mundane',
    'murky',
    'mushy',
    'musical',
    'mute',
    'muted',
    'mutual',
    'mysterious',
    'naive',
    'naked',
    'nappy',
    'narrow',
    'nasty',
    'national',
    'native',
    'natural',
    'naughty',
    'nauseating',
    'nauseous',
    'naval',
    'navy',
    'near',
    'nearby',
    'nearest',
    'neat',
    'nebulous',
    'necessary',
    'needed',
    'needless',
    'needy',
    'negative',
    'neighborly',
    'neighbouring',
    'nervous',
    'neutral',
    'new',
    'next',
    'nice',
    'nifty',
    'nimble',
    'nippy',
    'noble',
    'noiseless',
    'noisy',
    'nonchalant',
    'nondescript',
    'nondeterministic',
    'nonstop',
    'normal',
    'northern',
    'nostalgic',
    'nosy',
    'notable',
    'noted',
    'novel',
    'noxious',
    'nuclear',
    'null',
    'nullary',
    'numberless',
    'numero',
    'numerous',
    'nursing',
    'nutritious',
    'nutty',
    'oafish',
    'obedient',
    'obeisant',
    'objective',
    'obliged',
    'obliging',
    'oblique',
    'obnoxious',
    'obscene',
    'obsequious',
    'observant',
    'obsolete',
    'obtainable',
    'obtuse',
    'obvious',
    'occasional',
    'occupational',
    'oceanic',
    'odd',
    'odious',
    'offbeat',
    'official',
    'offline',
    'oily',
    'okay',
    'old',
    'olive',
    'olympic',
    'omniscient',
    'one',
    'onerous',
    'online',
    'only',
    'open',
    'operational',
    'opposite',
    'optical',
    'optimal',
    'optimistic',
    'optimum',
    'oral',
    'orange',
    'ordered',
    'ordinary',
    'organic',
    'organisational',
    'oriented',
    'original',
    'ornery',
    'orthodox',
    'orthogonal',
    'oscillating',
    'ossified',
    'other',
    'outdoor',
    'outer',
    'outgoing',
    'outrageous',
    'outside',
    'outstanding',
    'oval',
    'overall',
    'overcast',
    'overconfident',
    'overjoyed',
    'overrated',
    'overseas',
    'overt',
    'overwhelming',
    'overwrought',
    'pacific',
    'painful',
    'painstaking',
    'pale',
    'pallid',
    'paltry',
    'panicky',
    'panoramic',
    'paper',
    'parallel',
    'parched',
    'parental',
    'parliamentary',
    'parsimonious',
    'partial',
    'particular',
    'passing',
    'passive',
    'past',
    'pastoral',
    'pathetic',
    'patient',
    'payable',
    'peaceful',
    'peachy',
    'peculiar',
    'pedantic',
    'penitent',
    'pensive',
    'peppy',
    'perfect',
    'periodic',
    'permanent',
    'permissible',
    'perpendicular',
    'perpetual',
    'persistent',
    'personal',
    'petite',
    'philosophical',
    'phobic',
    'physical',
    'picayune',
    'picked',
    'piercing',
    'pink',
    'piquant',
    'pithy',
    'placid',
    'plain',
    'planar',
    'planned',
    'plant',
    'plastic',
    'plausible',
    'pleasant',
    'pleased',
    'pleasing',
    'plucky',
    'plum',
    'plumb',
    'poached',
    'poetic',
    'pointed',
    'pointless',
    'poised',
    'poky',
    'polished',
    'polite',
    'political',
    'polynomial',
    'poor',
    'popular',
    'posh',
    'positive',
    'possessive',
    'possible',
    'potent',
    'potential',
    'pounded',
    'powerful',
    'practical',
    'precious',
    'precise',
    'preferred',
    'pregnant',
    'preliminary',
    'premier',
    'premium',
    'prepared',
    'present',
    'presidential',
    'presto',
    'pretty',
    'previous',
    'pricey',
    'prickly',
    'primary',
    'prime',
    'primitive',
    'primo',
    'primordial',
    'principal',
    'printed',
    'prior',
    'private',
    'prized',
    'pro',
    'probable',
    'product',
    'productive',
    'professional',
    'profitable',
    'profound',
    'profuse',
    'progressive',
    'prominent',
    'promising',
    'promoted',
    'prompt',
    'proper',
    'proposed',
    'prospective',
    'protective',
    'protestant',
    'proud',
    'proven',
    'provincial',
    'psychedelic',
    'psychiatric',
    'psychological',
    'psychotic',
    'public',
    'puffy',
    'pumped',
    'punchy',
    'puny',
    'pure',
    'pureed',
    'purple',
    'purring',
    'pushy',
    'puzzled',
    'puzzling',
    'quack',
    'quadratic',
    'quaint',
    'qualified',
    'quality',
    'quantum',
    'quarrelsome',
    'querulous',
    'questionable',
    'quick',
    'quickest',
    'quiet',
    'quintessential',
    'quirky',
    'quixotic',
    'quizzical',
    'rabid',
    'racial',
    'rad',
    'radial',
    'radiant',
    'radical',
    'radioactive',
    'ragged',
    'rainy',
    'rambunctious',
    'rampant',
    'rancid',
    'random',
    'randomized',
    'rank',
    'rapid',
    'rare',
    'raspy',
    'rational',
    'ratty',
    'raw',
    'reach',
    'ready',
    'real',
    'realistic',
    'rear',
    'reasonable',
    'rebel',
    'recent',
    'receptive',
    'recondite',
    'rectilinear',
    'recursive',
    'red',
    'reduced',
    'redundant',
    'refined',
    'reflective',
    'regal',
    'regional',
    'registered',
    'regular',
    'regulatory',
    'related',
    'relative',
    'relaxed',
    'relaxing',
    'relevant',
    'reliable',
    'relieved',
    'religious',
    'reluctant',
    'remaining',
    'remarkable',
    'reminiscent',
    'remote',
    'renewed',
    'renewing',
    'representative',
    'repulsive',
    'required',
    'resident',
    'residential',
    'resilient',
    'resolute',
    'resolved',
    'resolving',
    'resonant',
    'respectable',
    'respectful',
    'respective',
    'responsible',
    'rested',
    'resultant',
    'resulting',
    'retail',
    'retired',
    'reverent',
    'revolutionary',
    'rhetorical',
    'rich',
    'ridiculous',
    'right',
    'righteous',
    'rightful',
    'rigid',
    'ripe',
    'rising',
    'ritzy',
    'rival',
    'roaring',
    'roasted',
    'robust',
    'rolling',
    'romantic',
    'roomy',
    'rooted',
    'rosy',
    'rotten',
    'rough',
    'round',
    'rounded',
    'rowdy',
    'royal',
    'rubber',
    'rubbery',
    'ruddy',
    'rude',
    'rugged',
    'ruling',
    'running',
    'rural',
    'rust',
    'rustic',
    'ruthless',
    'sable',
    'sacred',
    'sad',
    'safe',
    'salmon',
    'salty',
    'same',
    'sassy',
    'satisfactory',
    'satisfied',
    'satisfying',
    'saucy',
    'savage',
    'saved',
    'saving',
    'savory',
    'savvy',
    'scalding',
    'scandalous',
    'scarce',
    'scared',
    'scary',
    'scattered',
    'scenic',
    'scientific',
    'scintillating',
    'scornful',
    'scrawny',
    'screeching',
    'scruffy',
    'searing',
    'seasoned',
    'second',
    'secondary',
    'secret',
    'secretive',
    'secure',
    'sedate',
    'seemly',
    'seething',
    'select',
    'selected',
    'selective',
    'selfish',
    'semantic',
    'senile',
    'senior',
    'sensible',
    'sensitive',
    'separate',
    'serene',
    'serious',
    'settled',
    'settling',
    'several',
    'severe',
    'sexual',
    'shabby',
    'shaggy',
    'shaky',
    'shallow',
    'shared',
    'sharing',
    'sharp',
    'sheer',
    'shining',
    'shiny',
    'shivering',
    'shocked',
    'shocking',
    'short',
    'shortest',
    'showy',
    'shrewd',
    'shrill',
    'shrivelled',
    'shut',
    'shy',
    'sick',
    'sienna',
    'significant',
    'silent',
    'silky',
    'silly',
    'silver',
    'similar',
    'simmered',
    'simple',
    'simplistic',
    'sincere',
    'single',
    'singular',
    'sizzling',
    'skilled',
    'skillful',
    'skinny',
    'sleek',
    'sleepy',
    'slick',
    'slight',
    'slim',
    'slimy',
    'slippery',
    'sloppy',
    'slow',
    'sluggish',
    'small',
    'smart',
    'smashing',
    'smelly',
    'smiley',
    'smiling',
    'smoggy',
    'smoked',
    'smoky',
    'smooth',
    'snappy',
    'snazzy',
    'sneaky',
    'snobbish',
    'snotty',
    'snowy',
    'snugly',
    'social',
    'socialist',
    'soft',
    'soggy',
    'solar',
    'sole',
    'solid',
    'solitary',
    'soluble',
    'somber',
    'some',
    'sophisticated',
    'sordid',
    'sore',
    'sorry',
    'sought',
    'sound',
    'sour',
    'southern',
    'soviet',
    'spacial',
    'spare',
    'sparkling',
    'sparse',
    'spatial',
    'special',
    'specific',
    'specified',
    'spectacular',
    'speedy',
    'spicy',
    'spiffy',
    'spiky',
    'spiritual',
    'spiteful',
    'splendid',
    'spontaneous',
    'spooky',
    'sporting',
    'spotless',
    'spotted',
    'spotty',
    'spry',
    'spurious',
    'squalid',
    'square',
    'squealing',
    'squeamish',
    'stable',
    'staccato',
    'staff',
    'staking',
    'stale',
    'standard',
    'standing',
    'star',
    'stark',
    'static',
    'statistical',
    'statuesque',
    'statutory',
    'steadfast',
    'steady',
    'steamed',
    'steel',
    'steep',
    'stereotyped',
    'sterling',
    'stern',
    'sticky',
    'stiff',
    'still',
    'stimulating',
    'stingy',
    'stirred',
    'stirring',
    'stoic',
    'stone',
    'stormy',
    'straight',
    'straightforward',
    'strange',
    'strategic',
    'strict',
    'striking',
    'stringy',
    'striped',
    'strong',
    'structural',
    'stubborn',
    'stuck',
    'stunning',
    'stupefied',
    'stupendous',
    'stupid',
    'sturdy',
    'suave',
    'subdued',
    'subjective',
    'subsequent',
    'substantial',
    'subtle',
    'successful',
    'successive',
    'succinct',
    'succulent',
    'sudden',
    'sufficient',
    'sugary',
    'suitable',
    'suited',
    'sulky',
    'summary',
    'sunny',
    'sunset',
    'super',
    'superb',
    'superficial',
    'superior',
    'supporting',
    'supposed',
    'supreme',
    'sure',
    'surprised',
    'surprising',
    'surrounding',
    'surviving',
    'suspicious',
    'swank',
    'swanky',
    'swarm',
    'sweeping',
    'sweet',
    'swell',
    'sweltering',
    'swift',
    'symbolic',
    'symmetric',
    'sympathetic',
    'symptomatic',
    'synchronic',
    'synonymous',
    'syrupy',
    'systematic',
    'taboo',
    'tacit',
    'tacky',
    'talented',
    'tall',
    'tame',
    'tan',
    'tangible',
    'tangy',
    'tart',
    'tasteful',
    'tasteless',
    'tasty',
    'tattered',
    'tawdry',
    'taxonomic',
    'teaching',
    'teal',
    'tearful',
    'technical',
    'technological',
    'tedious',
    'teenage',
    'teeny',
    'telling',
    'temperate',
    'tempered',
    'temporary',
    'tender',
    'tense',
    'tenuous',
    'terminal',
    'ternary',
    'terrible',
    'terrific',
    'territorial',
    'tested',
    'testy',
    'thankful',
    'then',
    'theoretical',
    'therapeutic',
    'thick',
    'thin',
    'thinkable',
    'third',
    'thirsty',
    'thorough',
    'thoughtful',
    'thoughtless',
    'threadbare',
    'threaded',
    'threatening',
    'thriving',
    'thundering',
    'tidy',
    'tight',
    'timely',
    'timid',
    'tiny',
    'tired',
    'tiresome',
    'toasted',
    'together',
    'tolerant',
    'tomato',
    'toothsome',
    'top',
    'topical',
    'topped',
    'tops',
    'torpid',
    'tory',
    'tossed',
    'total',
    'touched',
    'touching',
    'tough',
    'touted',
    'towering',
    'toxic',
    'tractable',
    'traditional',
    'tragic',
    'tranquil',
    'trashy',
    'tremendous',
    'tricky',
    'trim',
    'trite',
    'tropical',
    'troubled',
    'truculent',
    'true',
    'trusted',
    'trusting',
    'trusty',
    'truthful',
    'try',
    'typical',
    'ubiquitous',
    'ugliest',
    'ugly',
    'ultimate',
    'ultra',
    'unable',
    'unacceptable',
    'unaccountable',
    'unadvised',
    'unarmed',
    'unary',
    'unaware',
    'unbecoming',
    'unbiased',
    'uncertain',
    'unchanged',
    'uncomfortable',
    'uncommon',
    'unconscious',
    'uncovered',
    'undecidable',
    'underground',
    'underlying',
    'understood',
    'undirected',
    'undisturbed',
    'unemployed',
    'unequal',
    'unequaled',
    'uneven',
    'unexpected',
    'unfair',
    'unfortunate',
    'unhappy',
    'unhealthy',
    'unified',
    'uniform',
    'unintelligent',
    'uninterested',
    'unique',
    'united',
    'universal',
    'unkempt',
    'unknown',
    'unlikely',
    'unnatural',
    'unnecessary',
    'unpleasant',
    'unproductive',
    'unruly',
    'unsightly',
    'unsolvable',
    'unsorted',
    'unsuitable',
    'untidy',
    'unused',
    'unusual',
    'unwavering',
    'unwieldy',
    'unwilling',
    'unwritten',
    'upbeat',
    'uplifting',
    'upper',
    'uppity',
    'upright',
    'upset',
    'uptight',
    'upward',
    'urban',
    'urbane',
    'urgent',
    'usable',
    'used',
    'useful',
    'useless',
    'usual',
    'utmost',
    'utopian',
    'utter',
    'uttermost',
    'vacuous',
    'vagabond',
    'vague',
    'vain',
    'valid',
    'valuable',
    'valued',
    'variable',
    'varied',
    'various',
    'varying',
    'vast',
    'vengeful',
    'venomous',
    'verbal',
    'verdant',
    'verified',
    'versed',
    'vertical',
    'very',
    'vestal',
    'viable',
    'vibrant',
    'vibrato',
    'vicarious',
    'vicious',
    'victorious',
    'vigorous',
    'vintage',
    'violent',
    'violet',
    'virulent',
    'visible',
    'visiting',
    'visual',
    'vital',
    'vitreous',
    'vivacious',
    'vivid',
    'vocal',
    'vocational',
    'vogue',
    'voiceless',
    'volatile',
    'volumetric',
    'voluminous',
    'voluntary',
    'voracious',
    'vulnerable',
    'wacky',
    'waggish',
    'waiting',
    'wakeful',
    'wandering',
    'wanted',
    'wanting',
    'warlike',
    'warm',
    'warped',
    'wary',
    'wasteful',
    'watery',
    'weak',
    'wealthy',
    'weary',
    'weathered',
    'wee',
    'weekly',
    'weighted',
    'weird',
    'welcome',
    'welcomed',
    'well',
    'western',
    'wet',
    'whimsical',
    'whispering',
    'white',
    'whole',
    'wholesale',
    'wicked',
    'wicker',
    'wide',
    'widespread',
    'wiggly',
    'wild',
    'wilful',
    'willing',
    'willowy',
    'wily',
    'windy',
    'winged',
    'winning',
    'wintry',
    'wired',
    'wiry',
    'wise',
    'wispy',
    'wistful',
    'wittering',
    'witty',
    'woebegone',
    'wonderful',
    'wondrous',
    'wood',
    'wooden',
    'woolen',
    'woozy',
    'workable',
    'working',
    'worldwide',
    'worn',
    'worried',
    'worrying',
    'worthwhile',
    'worthy',
    'wrathful',
    'wretched',
    'written',
    'wrong',
    'wry',
    'xenacious',
    'xenial',
    'xenogeneic',
    'xenophobic',
    'xeric',
    'xerothermic',
    'yabbering',
    'yammering',
    'yappiest',
    'yappy',
    'yawning',
    'yearling',
    'yearning',
    'yeasty',
    'yelling',
    'yellow',
    'yelping',
    'yielding',
    'yodelling',
    'young',
    'youngest',
    'youthful',
    'ytterbic',
    'yucky',
    'yummy',
    'zany',
    'zealous',
    'zenzeroth',
    'zestful',
    'zesty',
    'zingy',
    'zippy',
    'zonal',
    'zonked',
    'zoophagous',
    'zygomorphic',
    'zygotic',

]



SPORTS = [
    'archer',
    'arena',
    'arrow',
    'athlete',
    'axel',
    'badminton',
    'ball',
    'base',
    'batter',
    'bicycle',
    'bike',
    'bocce',
    'bow',
    'box',
    'canoe',
    'catch',
    'cleats',
    'club',
    'coach',
    'compete',
    'crew',
    'cricket',
    'cycle',
    'cyclist',
    'dart',
    'defense',
    'diamond',
    'dive',
    'diver',
    'exercise',
    'fencing',
    'field',
    'fitness',
    'frisbee',
    'game',
    'gear',
    'goal',
    'goalie',
    'golf',
    'golfer',
    'guard',
    'gym',
    'gymnast',
    'helmet',
    'hockey',
    'home',
    'hoop',
    'hoops',
    'infield',
    'inning',
    'javelin',
    'jog',
    'judo',
    'jump',
    'jumper',
    'karate',
    'kayak',
    'kites',
    'lacrosse',
    'league',
    'lose',
    'loser',
    'luge',
    'major',
    'mallet',
    'mat',
    'medal',
    'mitt',
    'move',
    'net',
    'offense',
    'olympics',
    'out',
    'paddle',
    'play',
    'player',
    'polo',
    'pool',
    'puck',
    'quarter',
    'quiver',
    'race',
    'racer',
    'referee',
    'relay',
    'ride',
    'rink',
    'row',
    'rower',
    'sail',
    'score',
    'scuba',
    'skate',
    'ski',
    'skier',
    'slalom',
    'sled',
    'sledder',
    'snowboard',
    'soccer',
    'sport',
    'squash',
    'stadium',
    'stick',
    'surfer',
    'swim',
    'swimmer',
    'tag',
    'target',
    'team',
    'tee',
    'tennis',
    'throw',
    'tie',
    'triathlon',
    'umpire',
    'volley',
    'walk',
    'weights',
    'win',
    'winner',
    'winning',
    'wrestler',

]



COMPUTER_SCIENCE = [
    'action',
    'ai',
    'alert',
    'algorithm',
    'alias',
    'allen',
    'alphabet',
    'antivirus',
    'app',
    'application',
    'argument',
    'array',
    'ascii',
    'assembly',
    'automaton',
    'backend',
    'bandwidth',
    'bash',
    'bin',
    'bintree',
    'bit',
    'block',
    'bluetooth',
    'boo',
    'boolean',
    'boot',
    'branch',
    'broadcast',
    'browser',
    'buffer',
    'bug',
    'build',
    'bus',
    'button',
    'byte',
    'c++',
    'cache',
    'capacity',
    'captcha',
    'character',
    'chip',
    'class',
    'click',
    'cluster',
    'code',
    'codeline',
    'command',
    'comment',
    'commit',
    'compiler',
    'compression',
    'computer',
    'configuration',
    'constants',
    'container',
    'cookies',
    'cores',
    'cpu',
    'cut',
    'daemon',
    'data',
    'database',
    'datatable',
    'debug',
    'declaration',
    'desktop',
    'developer',
    'device',
    'dictionary',
    'directory',
    'disk',
    'dns',
    'docker',
    'documents',
    'domains',
    'download',
    'drivers',
    'dsl',
    'email',
    'emulator',
    'encryption',
    'error',
    'ethernet',
    'event',
    'exception',
    'executable',
    'expression',
    'extension',
    'factor',
    'factorial',
    'file',
    'filter',
    'firewall',
    'float',
    'flow',
    'foo',
    'forloop',
    'fractals',
    'frame',
    'ftp',
    'functions',
    'gateway',
    'gif',
    'gigabyte',
    'github',
    'google',
    'gpu',
    'graphics',
    'hacker',
    'hardcode',
    'hardware',
    'hash',
    'heap',
    'hex',
    'host',
    'html',
    'http',
    'hyperlink',
    'icloud',
    'icon',
    'ide',
    'ifstatement',
    'image',
    'imap',
    'inline',
    'input',
    'instruction',
    'integer',
    'interface',
    'internet',
    'interpreter',
    'intranet',
    'ip',
    'iteration',
    'java',
    'javascript',
    'jpeg',
    'kernel',
    'keyword',
    'kilobyte',
    'lan',
    'language',
    'laptop',
    'link',
    'linux',
    'list',
    'literal',
    'load',
    'log',
    'login',
    'loop',
    'machine',
    'malware',
    'megabyte',
    'memory',
    'method',
    'microsoft',
    'mode',
    'module',
    'monitor',
    'motherboard',
    'multimedia',
    'negation',
    'network',
    'notebook',
    'null',
    'object',
    'operand',
    'operator',
    'output',
    'overflow',
    'package',
    'packet',
    'parameter',
    'parser',
    'passkey',
    'password',
    'patch',
    'path',
    'pattern',
    'performance',
    'petabyte',
    'phishing',
    'pixel',
    'pointer',
    'port',
    'prefix',
    'procedure',
    'process',
    'processor',
    'profile',
    'program',
    'programmer',
    'programming',
    'property',
    'protocol',
    'proxy',
    'python',
    'query',
    'queue',
    'ram',
    'reboot',
    'record',
    'recurrence',
    'recursion',
    'reduction',
    'relation',
    'reload',
    'reset',
    'rgb',
    'root',
    'router',
    'routine',
    'runtime',
    'scope',
    'screenshot',
    'script',
    'search',
    'segment',
    'sequence',
    'server',
    'set',
    'shebang',
    'shell',
    'simulation',
    'snippet',
    'software',
    'sort',
    'sourcecode',
    'spam',
    'stack',
    'stackoverflow',
    'storage',
    'strings',
    'stroustrup',
    'subroutine',
    'suffix',
    'supercomputer',
    'syntax',
    'system',
    'tail',
    'terabyte',
    'terminal',
    'text',
    'threads',
    'token',
    'toolbar',
    'torvalds',
    'torwalds',
    'touch',
    'transfer',
    'trojan',
    'truetype',
    'turing',
    'type',
    'unicode',
    'union',
    'unix',
    'upload',
    'uptime',
    'url',
    'usb',
    'user',
    'username',
    'utility',
    'variables',
    'view',
    'virus',
    'wan',
    'wifi',
    'windows',
    'workstation',
    'wozniak',
    'www',
    'xml',
    'yaml',
    'zip',

]



MISC = [
    'abbey',
    'accident',
    'account',
    'accrual',
    'actuary',
    'administrator',
    'agent',
    'agreement',
    'airport',
    'alley',
    'alternator',
    'analog',
    'analyst',
    'animation',
    'annuity',
    'antagonist',
    'anthology',
    'apartment',
    'appreciation',
    'armory',
    'asset',
    'assistant',
    'audit',
    'auditor',
    'avenue',
    'backpack',
    'backstory',
    'bag',
    'baggage',
    'bakery',
    'balance',
    'bank',
    'bankruptcy',
    'banquette',
    'barn',
    'barracks',
    'barrel',
    'barrier',
    'basin',
    'basket',
    'bench',
    'benefit',
    'book',
    'boom',
    'booster',
    'bottle',
    'boulevard',
    'bounce',
    'bowl',
    'bridge',
    'briefcase',
    'bucket',
    'budget',
    'bumper',
    'bungalow',
    'bunker',
    'buyer',
    'buyout',
    'cabana',
    'cabin',
    'cabinet',
    'cabriolet',
    'cafe',
    'caliper',
    'callable',
    'callback',
    'camera',
    'can',
    'canister',
    'canteen',
    'canvas',
    'capitol',
    'car',
    'carrier',
    'carton',
    'case',
    'cash',
    'cask',
    'casket',
    'chair',
    'chaise',
    'chalet',
    'change',
    'chapel',
    'chateau',
    'checkout',
    'chest',
    'church',
    'cinema',
    'claim',
    'clapper',
    'clerk',
    'clutch',
    'coffer',
    'collateral',
    'commission',
    'compressor',
    'comptroller',
    'concierge',
    'concourse',
    'condenser',
    'condominium',
    'conference',
    'confirmation',
    'consulate',
    'consultant',
    'contingency',
    'contract',
    'controller',
    'converter',
    'cooler',
    'coordinator',
    'copyright',
    'cost',
    'costume',
    'cottage',
    'couch',
    'coupe',
    'coverage',
    'crate',
    'credit',
    'credits',
    'dailies',
    'deadline',
    'debt',
    'decorator',
    'delay',
    'depot',
    'designer',
    'destination',
    'director',
    'dividend',
    'dolly',
    'door',
    'dormitory',
    'double',
    'dragster',
    'drawer',
    'drive',
    'driver',
    'duplex',
    'editor',
    'embassy',
    'engineer',
    'exit',
    'expenditure',
    'expense',
    'exposure',
    'extra',
    'facilitator',
    'factory',
    'fare',
    'film',
    'flannel',
    'flask',
    'flight',
    'folder',
    'foley',
    'fort',
    'foundry',
    'freeway',
    'funeral',
    'futon',
    'gaffer',
    'gain',
    'gallery',
    'garage',
    'gate',
    'gearbox',
    'genre',
    'glass',
    'gofer',
    'grip',
    'gutter',
    'hall',
    'hangar',
    'hatchback',
    'headline',
    'heater',
    'highway',
    'holder',
    'hospital',
    'hostel',
    'hotel',
    'hub',
    'humanist',
    'hutch',
    'hybrid',
    'igloo',
    'instructor',
    'interest',
    'inventory',
    'itinerary',
    'jail',
    'jar',
    'jeep',
    'joint',
    'kilometer',
    'kiosk',
    'kitchen',
    'laboratory',
    'layover',
    'lease',
    'ledger',
    'leisure',
    'level',
    'liability',
    'library',
    'lighthouse',
    'limit',
    'limo',
    'limousine',
    'loader',
    'loan',
    'locker',
    'lodge',
    'loft',
    'loveseat',
    'luggage',
    'mall',
    'manager',
    'manor',
    'mansion',
    'marina',
    'market',
    'membership',
    'metaphor',
    'microphone',
    'mileage',
    'mill',
    'minivan',
    'monastery',
    'monument',
    'mosque',
    'motel',
    'motor',
    'motorway',
    'museum',
    'myth',
    'officer',
    'orchestrator',
    'origin',
    'ottoman',
    'overpass',
    'pagoda',
    'paper',
    'parkway',
    'parody',
    'pass',
    'passenger',
    'passport',
    'pilot',
    'plan',
    'planner',
    'plot',
    'pocket',
    'pod',
    'porter',
    'pouch',
    'pouf',
    'price',
    'prison',
    'producer',
    'prop',
    'proposal',
    'protagonist',
    'pseudonym',
    'publicist',
    'purchase',
    'purse',
    'rack',
    'radiator',
    'ramp',
    'rate',
    'reader',
    'recordist',
    'rectory',
    'refinery',
    'refund',
    'rehab',
    'report',
    'restaurant',
    'road',
    'roadster',
    'roadway',
    'rotor',
    'sack',
    'satchel',
    'school',
    'seat',
    'sectional',
    'sedan',
    'seller',
    'sensor',
    'serif',
    'settee',
    'shares',
    'shed',
    'shop',
    'shot',
    'shoulder',
    'shrine',
    'sidewalk',
    'silo',
    'sofa',
    'spec',
    'specialist',
    'squib',
    'stable',
    'starter',
    'statement',
    'station',
    'stock',
    'stool',
    'store',
    'storyboard',
    'strategist',
    'stunt',
    'suitcase',
    'suite',
    'supervisor',
    'survey',
    'symbol',
    'synopsis',
    'table',
    'taxi',
    'technician',
    'tent',
    'theater',
    'ticket',
    'tin',
    'tote',
    'trainer',
    'transit',
    'travel',
    'tray',
    'trip',
    'triplex',
    'truck',
    'trunk',
    'trust',
    'tub',
    'tube',
    'tunnel',
    'university',
    'urn',
    'van',
    'vase',
    'velvet',
    'vendor',
    'wagon',
    'wardrobe',
    'watchtower',
    'wheel',
    'writer',

]



ARCHITECTURE = [
    'abacus',
    'accolade',
    'apron',
    'arcade',
    'arch',
    'architect',
    'archway',
    'arris',
    'atrium',
    'balcony',
    'baluster',
    'balustrade',
    'bargeboard',
    'basilica',
    'belvedere',
    'blobitecture',
    'blueprint',
    'bonneted',
    'bossage',
    'brace',
    'bracket',
    'bulwark',
    'burjalarab',
    'cancellus',
    'cant',
    'casement',
    'cathedral',
    'chimney',
    'cinquecento',
    'circulation',
    'colonnade',
    'column',
    'construction',
    'corbel',
    'cornice',
    'courtyard',
    'cresting',
    'crypt',
    'cryptoporticus',
    'cupola',
    'deconstruction',
    'dentil',
    'dentils',
    'design',
    'dimensions',
    'dome',
    'dormer',
    'eiffletower',
    'elevations',
    'engawa',
    'entablature',
    'ergonomy',
    'exterior',
    'facade',
    'fanlights',
    'fenestration',
    'finial',
    'floor',
    'foil',
    'foundation',
    'frieze',
    'gable',
    'gallerie',
    'gargoyle',
    'gazebo',
    'infrastructure',
    'intercolumniation',
    'interior',
    'jettying',
    'keystone',
    'landscaping',
    'loculus',
    'loggia',
    'lunette',
    'mascaron',
    'masonry',
    'minaret',
    'molding',
    'mortise',
    'mullion',
    'muntin',
    'nave',
    'oculus',
    'palladian',
    'panel',
    'parapet',
    'patio',
    'pavilion',
    'pediment',
    'pelmet',
    'pergola',
    'phiale',
    'pier',
    'pilaster',
    'plaza',
    'plinth',
    'portcullis',
    'portico',
    'projections',
    'quoin',
    'raincap',
    'roof',
    'rotunda',
    'roundel',
    'saltbox',
    'sash',
    'setback',
    'sidelight',
    'skyscraper',
    'soffit',
    'spandrel',
    'spire',
    'stoop',
    'structure',
    'symmetries',
    'tajmahal',
    'tenon',
    'terrace',
    'tower',
    'tracery',
    'transom',
    'triglyph',
    'truss',
    'turret',
    'tympanum',
    'undercroft',
    'urbanism',
    'vault',
    'veranda',
    'void',

]



BIOLOGY = [
    'abdomen',
    'abiogenesis',
    'absorption',
    'adaptation',
    'adhesion',
    'agonist',
    'aldosterone',
    'algae',
    'allantois',
    'ammonification',
    'amnion',
    'amniotes',
    'amoeba',
    'anabolism',
    'anaphase',
    'anaplasia',
    'anatomy',
    'angiosperm',
    'animal',
    'antenna',
    'anthropometry',
    'antibiotic',
    'antioxidant',
    'aorta',
    'apoplexy',
    'apoptosis',
    'appendage',
    'arthropod',
    'astrobiology',
    'atavism',
    'atrophy',
    'autoimmunity',
    'autophagy',
    'autopsy',
    'autosomes',
    'autotroph',
    'auxin',
    'axon',
    'benthos',
    'bilirubin',
    'biogeography',
    'biologist',
    'biomass',
    'biome',
    'biomechanics',
    'biomimicry',
    'biophysics',
    'biopsy',
    'biosensor',
    'bipedalism',
    'bivalve',
    'blastocyst',
    'blood',
    'botany',
    'bovine',
    'brain',
    'bronchioles',
    'bryophyte',
    'calmodulin',
    'carcinoma',
    'carotenoids',
    'carrion',
    'cartilage',
    'catabolism',
    'centromere',
    'ceruloplasmin',
    'chemiosmosis',
    'chemoautotroph',
    'chemoheterotroph',
    'chemokines',
    'chemosynthesis',
    'chitin',
    'chlorophyll',
    'chloroplast',
    'chlorosis',
    'chordate',
    'chorion',
    'chyme',
    'cilium',
    'clade',
    'cladistics',
    'cladogram',
    'cloaca',
    'cloning',
    'codominance',
    'coelom',
    'coevolution',
    'cofactor',
    'colony',
    'commensalism',
    'community',
    'competition',
    'consumer',
    'copepod',
    'crenation',
    'cristae',
    'cryobiology',
    'crystallization',
    'cultivar',
    'curare',
    'cytokinesis',
    'cytolysis',
    'cytoplasm',
    'cytoskeleton',
    'cytosol',
    'darwin',
    'denature',
    'dendrite',
    'desmosomes',
    'detritivore',
    'deuterostome',
    'diastole',
    'diatom',
    'dicot',
    'disaccharide',
    'dobzhansky',
    'domain',
    'ear',
    'ecdysis',
    'echinoderm',
    'ecology',
    'ecosystem',
    'ecotype',
    'ectoderm',
    'ectotherm',
    'egg',
    'embryo',
    'embryology',
    'emulsify',
    'endemism',
    'endoderm',
    'endoskeleton',
    'endosperm',
    'endothelium',
    'epidemiology',
    'epiphyte',
    'epistasis',
    'esophagus',
    'estrogen',
    'ethology',
    'eubacteria',
    'eukaryote',
    'euphoria',
    'euthymic',
    'evolution',
    'excretion',
    'exocytosis',
    'exoskeleton',
    'extinction',
    'extirpation',
    'extremophile',
    'eyes',
    'fat',
    'fauna',
    'fecundity',
    'fertilization',
    'fetus',
    'filtration',
    'flagella',
    'flower',
    'fluoride',
    'foot',
    'forest',
    'formaldehyde',
    'fossils',
    'frenulum',
    'fungi',
    'gamete',
    'gametophyte',
    'gastrulation',
    'genetics',
    'genotype',
    'genus',
    'geriatrics',
    'germination',
    'gerontology',
    'gibberellin',
    'gland',
    'gluconeogenesis',
    'glycerol',
    'glycogen',
    'glycogenesis',
    'glycogenolysis',
    'gonad',
    'gradualism',
    'gravitropism',
    'gymnosperm',
    'head',
    'heart',
    'hematopoiesis',
    'heme',
    'herbaceous',
    'heredity',
    'hermaphrodite',
    'herpetology',
    'heterotroph',
    'heterozygous',
    'hibernation',
    'histology',
    'homeostasis',
    'homolog',
    'homoplasy',
    'hormone',
    'horticulture',
    'hydrolyze',
    'hyperosmotic',
    'hyperplasia',
    'imago',
    'interphase',
    'invertebrate',
    'irradiation',
    'kingdom',
    'labia',
    'lactase',
    'larva',
    'leaf',
    'legume',
    'lesion',
    'leukocyte',
    'ligand',
    'linneus',
    'lipolysis',
    'liposome',
    'liver',
    'liverworts',
    'lymph',
    'lyse',
    'lysosome',
    'maceration',
    'macroevolution',
    'macromolecule',
    'macrophage',
    'mastication',
    'meiosis',
    'mendel',
    'meristem',
    'mesentery',
    'mesoderm',
    'metamerism',
    'metamorphosis',
    'metaphase',
    'metastasize',
    'methanol',
    'microevolution',
    'microfilament',
    'microorganisms',
    'microscope',
    'microtubule',
    'miosis',
    'mitochondria',
    'mitochondrion',
    'mitosis',
    'molecules',
    'monera',
    'monocot',
    'monomer',
    'monosomy',
    'morphology',
    'mosses',
    'motility',
    'mucus',
    'multicellular',
    'muscle',
    'mutualism',
    'mycology',
    'mycorrhizae',
    'myofibril',
    'nephrology',
    'nephron',
    'neurogenesis',
    'neuron',
    'neuroscience',
    'niche',
    'nucleoid',
    'omnivore',
    'oncology',
    'organ',
    'organelle',
    'organism',
    'ornithology',
    'ovary',
    'overpopulation',
    'ovule',
    'paleontology',
    'parasite',
    'parasitism',
    'parasitology',
    'parenchyma',
    'paroxysm',
    'pathobiology',
    'pathology',
    'pedigree',
    'peroxisome',
    'perspiration',
    'petiole',
    'phagocytosis',
    'phalanx',
    'pharmacology',
    'pharynx',
    'phenotype',
    'phloem',
    'phospholipid',
    'photoautotroph',
    'photosynthesis',
    'phototropism',
    'phylogeny',
    'phylum',
    'physiology',
    'phytoplankton',
    'pinocytosis',
    'placenta',
    'plant',
    'plasmolysis',
    'pollen',
    'polyp',
    'populations',
    'pore',
    'porphyrin',
    'predation',
    'predator',
    'prey',
    'primates',
    'progesterone',
    'prokaryote',
    'prometaphase',
    'prophase',
    'prosthesis',
    'proteolysis',
    'protists',
    'protoplasm',
    'protostome',
    'protozoa',
    'pseudopod',
    'pyruvate',
    'raptor',
    'reptile',
    'rhizome',
    'roots',
    'saprophyte',
    'sarcolemma',
    'sarcomere',
    'schwann',
    'seashell',
    'secretion',
    'seed',
    'skeleton',
    'skin',
    'speciation',
    'species',
    'sperm',
    'spirochete',
    'spleen',
    'sporangium',
    'spore',
    'sporophyte',
    'stamen',
    'stem',
    'steroid',
    'stoma',
    'stomach',
    'stroma',
    'substrate',
    'sucrose',
    'symbiont',
    'symbiosis',
    'synapomorphy',
    'synapsis',
    'systole',
    'taxon',
    'taxonomy',
    'teeth',
    'telophase',
    'testosterone',
    'thigmotropism',
    'thorax',
    'tissue',
    'tonicity',
    'toxicity',
    'toxicology',
    'toxin',
    'trait',
    'transferrin',
    'transpiration',
    'tropism',
    'turgid',
    'unicellular',
    'urethra',
    'urine',
    'uterus',
    'vacuole',
    'vasodilation',
    'vertebrate',
    'vesicle',
    'viviparous',
    'vivisection',
    'xylem',
    'zonation',
    'zoology',
    'zooplankton',
    'zygospore',
    'zygote',

]



SCIENTISTS = [
    'agnesi',
    'albattani',
    'allen',
    'almeida',
    'ampere',
    'archimedes',
    'ardinghelli',
    'aryabhata',
    'austin',
    'avogadro',
    'babbage',
    'banach',
    'bernard',
    'bernerslee',
    'bernoulli',
    'bohr',
    'boltzmann',
    'brahmagupta',
    'brenner',
    'cauchy',
    'celsius',
    'copernicus',
    'coulomb',
    'crick',
    'curie',
    'darwin',
    'davinci',
    'dobshansky',
    'dobzhansky',
    'edison',
    'ehrlich',
    'einstein',
    'euclid',
    'euler',
    'faraday',
    'fermi',
    'feynman',
    'fibonacci',
    'fischer',
    'fleming',
    'franklin',
    'fransworth',
    'freud',
    'galileo',
    'galvani',
    'goddard',
    'goldwasser',
    'gutenberg',
    'hawking',
    'heisenberg',
    'helmholtz',
    'hubble',
    'irving',
    'kelvin',
    'kepler',
    'kimura',
    'koch',
    'kolmogorov',
    'kraepelin',
    'lamarck',
    'laplace',
    'lederberg',
    'leeuwenhoek',
    'linnaeus',
    'lorentz',
    'mandelbrot',
    'marconi',
    'maxwell',
    'mcclintock',
    'mendel',
    'mendeleev',
    'morse',
    'neumann',
    'newton',
    'nobel',
    'oppenheimer',
    'pascal',
    'pasteur',
    'pauling',
    'pavlov',
    'planck',
    'pythagoras',
    'ramanujan',
    'raoult',
    'riemann',
    'roentgen',
    'rutherford',
    'schrodinger',
    'shannon',
    'tesla',
    'torvalds',
    'turing',
    'venter',
    'volta',
    'watson',
    'watt',
    'wegener',
    'wilson',
    'wozniak',
    'yamanaka',
    'youyou',

]



MATH = [
    'abscissa',
    'adjugate',
    'algebra',
    'angle',
    'apex',
    'archimedes',
    'ardinghelli',
    'area',
    'arithmetic',
    'aryabhata',
    'axis',
    'banach',
    'basis',
    'bernoulli',
    'bisector',
    'calculus',
    'cauchy',
    'center',
    'centroid',
    'cevian',
    'circle',
    'combination',
    'cone',
    'congruence',
    'consimilarity',
    'coordinate',
    'cosine',
    'couple',
    'cube',
    'curve',
    'cylinder',
    'degree',
    'denominator',
    'derivative',
    'determinant',
    'diagonal',
    'diameter',
    'differential',
    'dimension',
    'discriminant',
    'dodecagon',
    'edge',
    'envelope',
    'equation',
    'euclid',
    'euler',
    'exponent',
    'fibonacci',
    'flag',
    'focus',
    'formula',
    'fractal',
    'fraction',
    'function',
    'gauss',
    'geometry',
    'graph',
    'grid',
    'height',
    'hexagon',
    'hypotenuse',
    'identity',
    'incircle',
    'independence',
    'integral',
    'intersection',
    'inverse',
    'inversion',
    'involute',
    'kolmogorov',
    'laplace',
    'legs',
    'line',
    'locus',
    'logarithm',
    'mandelbrot',
    'manifold',
    'mapping',
    'matrix',
    'mean',
    'median',
    'midpoint',
    'minute',
    'model',
    'monoid',
    'multiplication',
    'neumann',
    'node',
    'norm',
    'normal',
    'number',
    'numbertheory',
    'octagon',
    'pentagon',
    'perimeter',
    'plane',
    'point',
    'poisson',
    'polygon',
    'polynomial',
    'prime',
    'probability',
    'projection',
    'proof',
    'pyramid',
    'pythagoras',
    'radian',
    'ramanujan',
    'range',
    'rank',
    'ratio',
    'rational',
    'ray',
    'rectangle',
    'resultant',
    'rhombus',
    'riemann',
    'secant',
    'settheory',
    'shannon',
    'similarity',
    'sine',
    'slide',
    'solid',
    'span',
    'sphere',
    'square',
    'statistic',
    'statistics',
    'subspace',
    'surface',
    'symmetry',
    'tangent',
    'tensor',
    'tessellation',
    'tetrad',
    'thales',
    'theorem',
    'transformation',
    'transpose',
    'triangle',
    'trigonometry',
    'variable',
    'vector',
    'vertex',
    'web',

]



"""Generate unique, human-readable, and memorable names or identifiers"""

from dataclasses import dataclass
import random
from typing import Dict, NamedTuple, Union, List

from . import data

__version__ = '0.9.0'


SUFFIX_ALPHABET = '0123456789abcdefghijklmnopqrstuvwxyz'


def _generate(
        category: Union[str, List[str]] = '',
        suffix_length: int = 0,
        style: str = 'lowercase'
) -> List[str]:
    """
    Generate a random name composed of an adjective and a noun from a specified
    or randomly chosen category, with an optional random suffix.

    Args:
        category (Union[str, List[str]]): 
            The category or list of categories to choose the noun from.
        suffix_length (int): 
            The length of the optional random suffix.
        style (str):
            The style to apply to the generated name ('lowercase', 'uppercase', 
            'capitalize').

    Returns:
        List[str]: A list containing the adjective, noun, and optional suffix.

    Raises:
        ValueError: If the specified category does not exist.
    """
    adjective = random.choice(data.ADJECTIVES)
    
    # Determine the category name
    if not category or category == '__all__':
        category_name = random.choice(list(data.categories.keys()))
    elif isinstance(category, list):
        category_name = random.choice(category)
    else:
        category_name = category

    if category_name not in data.categories:
        raise ValueError(f'Category {category_name} does not exist.')

    # Pick a random noun from the chosen category
    noun_list = random.choice(data.categories[category_name])
    noun = random.choice(noun_list)

    # Create a list with the adjective and noun
    name_parts = [adjective, noun]

    # Add a random suffix if specified
    if suffix_length:
        suffix = ''.join(random.choices(SUFFIX_ALPHABET, k=suffix_length))
        name_parts.append(suffix)

    # Apply style transformation if specified
    if style == 'uppercase':
        name_parts = [part.upper() for part in name_parts]
    elif style == 'capitalize':
        name_parts = [part.capitalize() for part in name_parts]

    return name_parts


def generate(*args, separator='_', **kwargs) -> str:
    """
    Wrapper for the `_generate` function to return the string name.

    Args:
        separator (str): 
            The separator between the adjective, noun, and suffix.

    Returns:
        str: The generated name.
    """
    name_parts = _generate(*args, **kwargs)
    return separator.join(name_parts)


def list_categories() -> List[str]:
    """Returns a sorted list of all available categories."""
    return sorted(data.categories.keys())


@dataclass
class Stat:
    noun_count: int
    example_name: str
    name_combinations: int
    id_combinations: int

def stats(suffix_length: int = 4) -> Dict[str, Stat]:
    """
    Generate statistics for each category:
    - Number of nouns
    - Example name
    - Number of possible name combinations
    - Number of possible ID combinations

    Returns:
        Dict[str, Stat]: A dictionary where keys are category names
        and values are instances of the Stat named tuple containing
        the calculated statistics.
    """
    adjective_count = len(data.ADJECTIVES)

    # Count total nouns from all categories
    all_nouns = set()
    for subcategories in data.categories.values():
        for subcategory in subcategories:
            all_nouns.update(subcategory)
    stats = {'__all__': len(all_nouns)}

    # Count nouns in each category
    for category, subcategories in data.categories.items():
        stats[category] = sum(len(nouns) for nouns in subcategories)

    # Generate example name and number of combinations for each category
    for category in stats:
        noun_count = stats[category]
        name_combinations = adjective_count * noun_count
        id_combinations = name_combinations * (len(SUFFIX_ALPHABET) ** suffix_length)
        example_name = generate(category=category)
        stats[category] = Stat(
            noun_count=noun_count,
            example_name=example_name,
            name_combinations=name_combinations,
            id_combinations=id_combinations,
        )
    
    return stats


HISTORY = [
    'age',
    'antiquity',
    'archeology',
    'archive',
    'artemis',
    'artifact',
    'aztec',
    'babylon',
    'battle',
    'beowulf',
    'biography',
    'bronzeage',
    'byzantium',
    'caesar',
    'calendar',
    'caligula',
    'castle',
    'censor',
    'century',
    'chronicle',
    'chronology',
    'churchill',
    'civilization',
    'classic',
    'cleopatra',
    'colonization',
    'columbus',
    'confucianism',
    'confucius',
    'conqueror',
    'conquest',
    'constantine',
    'constitution',
    'corinth',
    'crusades',
    'culture',
    'date',
    'dday',
    'democritus',
    'dickens',
    'dictator',
    'dictatorship',
    'diomedes',
    'dionysos',
    'document',
    'druid',
    'dynasty',
    'emperor',
    'empire',
    'epoch',
    'era',
    'eros',
    'expedition',
    'feudalism',
    'fortress',
    'glyphs',
    'goebbels',
    'heritage',
    'hippocrates',
    'historian',
    'history',
    'hitler',
    'homer',
    'iliad',
    'imperialism',
    'invasion',
    'ironage',
    'jefferson',
    'journal',
    'kennedy',
    'king',
    'kingdoms',
    'knight',
    'lancelot',
    'legion',
    'lenin',
    'lincoln',
    'lombards',
    'luther',
    'mandela',
    'manuscript',
    'marcopolo',
    'marx',
    'mesopotamia',
    'michelangelo',
    'midas',
    'monarchy',
    'mussolini',
    'mythology',
    'napoleon',
    'nero',
    'nietzsche',
    'nomad',
    'odin',
    'odysseus',
    'odyssey',
    'olympia',
    'orpheus',
    'ostracism',
    'palace',
    'pandora',
    'perseus',
    'pharaoh',
    'pocahontas',
    'pompeii',
    'poseidon',
    'prehistory',
    'provenance',
    'pyramids',
    'quaestor',
    'queen',
    'ragnar',
    'ragnarok',
    'rebellion',
    'reformation',
    'renaissance',
    'revolution',
    'rome',
    'roosevelt',
    'saga',
    'samurai',
    'sanskrit',
    'scripts',
    'seneca',
    'settlement',
    'shogun',
    'sparta',
    'spartacus',
    'sphinx',
    'stalin',
    'stoneage',
    'stonehenge',
    'sumerians',
    'sword',
    'tacitus',
    'temple',
    'thor',
    'time',
    'totalitarianism',
    'trade',
    'treaty',
    'troy',
    'tudor',
    'valhalla',
    'viking',
    'voltaire',
    'war',
    'warfare',
    'washington',

]



from .adjectives import ADJECTIVES
from .animals import ANIMALS
from .architecture import ARCHITECTURE
from .astronomy import ASTRONOMY
from .chemistry import CHEMISTRY
from .computer_science import COMPUTER_SCIENCE
from .countries import COUNTRIES
from .food import FOOD
from .geography import GEOGRAPHY
from .history import HISTORY
from .math import MATH
from .microbiology import MICROBIOLOGY
from .molecular_biology import MOLECULAR_BIOLOGY
from .music import MUSIC
from .physics import PHYSICS
from .plants import PLANTS
from .scientists import SCIENTISTS
from .sports import SPORTS
from .misc import MISC

categories = {
    'animals': [ANIMALS],
    'architecture': [ARCHITECTURE],
    'astronomy': [ASTRONOMY],
    'biology': [
        ANIMALS,
        PLANTS,
        MICROBIOLOGY,
        MOLECULAR_BIOLOGY,
    ],
    'chemistry': [CHEMISTRY],
    'countries': [COUNTRIES],
    'computer_science': [COMPUTER_SCIENCE],
    'food': [FOOD],
    'geography': [GEOGRAPHY],
    'history': [HISTORY],
    'math': [MATH],
    'microbiology': [MICROBIOLOGY],
    'misc': [MISC],
    'molecular_biology': [MOLECULAR_BIOLOGY],
    'music': [MUSIC],
    'physics': [PHYSICS],
    'plants': [PLANTS],
    'science': [
        ASTRONOMY,
        CHEMISTRY,
        MICROBIOLOGY,
        MOLECULAR_BIOLOGY,
        PHYSICS,
    ],
    'scientists': [SCIENTISTS],
    'sports': [SPORTS],
}


FOOD = [
    'aroma',
    'asadero',
    'asiago',
    'bagel',
    'beans',
    'beer',
    'biscuit',
    'blue',
    'bread',
    'brick',
    'brie',
    'broth',
    'burger',
    'burrata',
    'burrito',
    'butter',
    'butterkase',
    'cake',
    'camembert',
    'candy',
    'caramel',
    'caviar',
    'cheddar',
    'cheese',
    'cheeseburger',
    'cheesesteak',
    'chili',
    'chimichanga',
    'chives',
    'chocolate',
    'chutney',
    'cider',
    'clubhouse',
    'cobbler',
    'cocoa',
    'coffee',
    'colby',
    'cookie',
    'cotija',
    'cousine',
    'cream',
    'croissant',
    'crumble',
    'cuisine',
    'curd',
    'dessert',
    'dish',
    'donut',
    'drink',
    'edam',
    'eggs',
    'emmentaler',
    'empanada',
    'enchilada',
    'entree',
    'feta',
    'filet',
    'fish',
    'flour',
    'fontina',
    'food',
    'fries',
    'garlic',
    'ginger',
    'glaze',
    'gorgonzola',
    'gouda',
    'grill',
    'hamburger',
    'havarti',
    'honey',
    'horseradish',
    'hotdog',
    'ice',
    'juice',
    'kasseri',
    'ketchup',
    'lard',
    'limburger',
    'liquor',
    'margarine',
    'marinade',
    'mascarpone',
    'mayo',
    'mayonnaise',
    'meat',
    'milk',
    'mint',
    'miso',
    'mousse',
    'mozzarella',
    'muenster',
    'muffin',
    'mushroom',
    'mustard',
    'noodle',
    'nugget',
    'nut',
    'oil',
    'olive',
    'omelette',
    'onion',
    'pan',
    'panini',
    'parmesan',
    'pasta',
    'paste',
    'pastry',
    'pepato',
    'pepper',
    'pesto',
    'pie',
    'pita',
    'pizza',
    'plate',
    'pot',
    'poutine',
    'pretzel',
    'provolone',
    'pudding',
    'queso',
    'raclette',
    'recipe',
    'relish',
    'remoulade',
    'reuben',
    'rice',
    'ricotta',
    'roll',
    'romano',
    'salad',
    'salsa',
    'sandwich',
    'sauce',
    'sauerkraut',
    'seasoning',
    'skillet',
    'slider',
    'soda',
    'sopapillas',
    'soup',
    'soy',
    'spice',
    'sriracha',
    'steak',
    'stew',
    'sugar',
    'sweets',
    'swiss',
    'syrup',
    'taco',
    'taquito',
    'tartar',
    'taste',
    'tea',
    'toast',
    'tostada',
    'vinegar',
    'waffle',
    'wasabi',
    'water',
    'wheat',
    'wine',
    'wok',
    'wrap',
    'yeast',
    'yogurt',

]



ASTRONOMY = [
    'albattani',
    'andromeda',
    'antimatter',
    'aphelion',
    'apoapsis',
    'apogee',
    'apollo',
    'appulse',
    'aquarius',
    'asterism',
    'asteroid',
    'astrogeology',
    'astrometry',
    'astronaut',
    'astronomer',
    'astronomy',
    'austin',
    'barycenter',
    'bigbang',
    'blackbody',
    'blazar',
    'brightness',
    'capricornus',
    'centaur',
    'chromosphere',
    'comet',
    'conjunction',
    'constellation',
    'copernicus',
    'core',
    'corona',
    'cosmogony',
    'cosmology',
    'crater',
    'dust',
    'dwarf',
    'earth',
    'eclipse',
    'equinox',
    'exoplanet',
    'flux',
    'fusions',
    'galaxy',
    'galileo',
    'hadron',
    'halo',
    'heliosphere',
    'hubble',
    'hypergalaxy',
    'ionosphere',
    'isochrone',
    'jupiter',
    'kepler',
    'kuiperbelt',
    'lepton',
    'lonosphere',
    'luminosity',
    'lunar',
    'magnetosphere',
    'magnitude',
    'mars',
    'mercury',
    'meteor',
    'meteorite',
    'meteoroid',
    'micrometeoroid',
    'milkyway',
    'moon',
    'multiverse',
    'nasa',
    'nebula',
    'neptune',
    'neutrino',
    'nova',
    'observatory',
    'occultation',
    'omega',
    'opacity',
    'orbit',
    'orion',
    'parallax',
    'parsec',
    'penumbra',
    'perturbation',
    'photometry',
    'photosphere',
    'planet',
    'planetarium',
    'planetoid',
    'polaris',
    'protoplanet',
    'protostar',
    'pulsar',
    'quasar',
    'radius',
    'rainbow',
    'redshift',
    'relativity',
    'rocket',
    'rover',
    'sagittarius',
    'satellite',
    'saturn',
    'scintillation',
    'scorpius',
    'singularity',
    'sirius',
    'sky',
    'solstice',
    'space',
    'spacecraft',
    'star',
    'sun',
    'sunspot',
    'supercluster',
    'supernova',
    'telescope',
    'twilight',
    'universe',
    'uranus',
    'vacuum',
    'venus',
    'zenith',
    'zodiac',

]



PHYSICS = [
    'aberration',
    'acceleration',
    'acre',
    'advection',
    'airwatt',
    'albedo',
    'ampere',
    'amplitude',
    'aperture',
    'atom',
    'bar',
    'baryon',
    'bhabha',
    'bifocal',
    'body',
    'bohr',
    'boltzmann',
    'booth',
    'candela',
    'capacitor',
    'celsius',
    'chain',
    'circuit',
    'conduction',
    'conductor',
    'convection',
    'coulomb',
    'crest',
    'current',
    'cyclotron',
    'dalton',
    'decibel',
    'density',
    'diffraction',
    'diffusion',
    'dioptre',
    'dispersion',
    'displacement',
    'distance',
    'distortion',
    'edison',
    'einstein',
    'electricity',
    'electron',
    'energy',
    'farad',
    'faraday',
    'feynman',
    'fields',
    'fluid',
    'force',
    'frequencies',
    'friction',
    'fusion',
    'gallon',
    'gram',
    'gravity',
    'heisenberg',
    'henry',
    'hertz',
    'impulse',
    'inch',
    'inertia',
    'insulator',
    'joule',
    'laser',
    'lens',
    'light',
    'lorentz',
    'lumen',
    'magnet',
    'magnification',
    'marconi',
    'maser',
    'masses',
    'matter',
    'meter',
    'mile',
    'mirror',
    'momentum',
    'neutron',
    'newton',
    'nucleus',
    'ohm',
    'optics',
    'ounce',
    'particle',
    'pascal',
    'period',
    'photon',
    'pint',
    'planck',
    'polarization',
    'positron',
    'potential',
    'pound',
    'power',
    'pressure',
    'prism',
    'projectile',
    'proton',
    'quanta',
    'quantum',
    'quark',
    'quart',
    'radiation',
    'reflection',
    'refraction',
    'resistivity',
    'resonance',
    'scalar',
    'scattering',
    'second',
    'shift',
    'solenoid',
    'spectrum',
    'speed',
    'strain',
    'stress',
    'tesla',
    'thrust',
    'ton',
    'torque',
    'trough',
    'velocity',
    'vibration',
    'volt',
    'volta',
    'voltage',
    'watt',
    'wave',
    'wavelength',
    'weight',
    'work',
    'yard',

]



import argparse
import sys
from typing import Optional

import namer

def get_parser() -> argparse.ArgumentParser:
    parser = argparse.ArgumentParser(
        prog='namer',
        description=f'namer v.{namer.__version__}: Generate unique, '
        'human-readable, and memorable names or identifiers',
        add_help=False
    )
    
    parser.add_argument(
        '-v', '--version',
        action='version',
        version=namer.__version__,
        help="Show the tool's version and exit"
    )
    parser.add_argument(
        '-h', '--help',
        action='help',
        help='Show this help message and exit'
    )

    subparsers = parser.add_subparsers(dest='command')
    stats_parser = subparsers.add_parser(
        'stats',
        help='Show statistics on available categories and number of name '
            'combinations',
        add_help=False
    )
    generate_parser = subparsers.add_parser(
        'generate',
        help='Generate unique names/IDs',
        add_help=False
    )
    generate_parser.add_argument(
        'count',
        type=int,
        help='Number of unique names/IDs to generate'
    )
    generate_parser.add_argument(
        '--category',
        action='append',
        choices=namer.list_categories(),
        metavar='<str>',
        default=[],
        help='Category to generate names from. Can be specified multiple '
            'times. Default to all categories.'
    )
    generate_parser.add_argument(
        '--suffix_length',
        type=int,
        metavar='<int>',
        default=0,
        help='Length of the optional random suffix. Set to 0 for no suffix '
           '[default: %(default)s]'
    )
    generate_parser.add_argument(
        '--separator',
        metavar='<str>',
        default='-',
        help='Separator between the words in name/ID '
            '[default: %(default)s]'
    )
    generate_parser.add_argument(
        '--style',
        choices=('lowercase', 'uppercase', 'capitalize'),
        default='lowercase',
        help='Text style for the generated name [default: %(default)s]'
    )

    # Show help message if the script is run without any arguments.
    if len(sys.argv[1:]) == 0:
        parser.print_help()
        parser.exit()

    # Show the generate subparser help message
    # if it is run without any arguments.
    if sys.argv[-1] == 'generate':
        generate_parser.print_help()
        parser.exit()

    return parser


def print_stats_table(sep: Optional[str] = '  ') -> None:
    """
    Print a table with statistics for each category.

    Args:
        sep (str, optional): Separator used to separate columns in the table. 
    """
    stats = namer.stats()

    # Determine column widths
    category_column_width = max(len(category) for category in stats)
    example_column_width = max(len(stat.example_name) for stat in stats.values())
    nouns_column_width = 5
    combs_column_width = 10

    # Table header
    header = [
        f"{'Category':{category_column_width}}",
        f"{'Nouns':{nouns_column_width}}",
        f"{'Example':{example_column_width}}",
        f"{'Name_combs':>{combs_column_width}}",
        f"{'ID_combs (4-char suffix)':}"
    ]
    print(sep.join(header))

    # Table body
    for category, stat in stats.items():
        row = [
            f"{category:{category_column_width}}",
            f"{stat.noun_count:{nouns_column_width}}",
            f"{stat.example_name:{example_column_width}}",
            f"{stat.name_combinations:>{combs_column_width},}",
            f"{stat.id_combinations:.0e}"
        ]
        print(sep.join(row))

def main():
    parser = get_parser()
    args = parser.parse_args()

    if args.command == 'stats':
        print_stats_table()
    elif args.command == 'generate':
        for i in range(args.count):
            name = namer.generate(
                category=args.category,
                suffix_length=args.suffix_length,
                separator=args.separator,
                style=args.style
            )
            print(name)



if __name__ == '__main__':
    main()


ANIMALS = [
    'aardvark',
    'aardwolf',
    'adder',
    'albatross',
    'alligator',
    'alpaca',
    'amberjack',
    'amphibian',
    'anaconda',
    'anchovy',
    'angelfish',
    'angler',
    'anglerfish',
    'angora',
    'ant',
    'anteater',
    'antelope',
    'antlion',
    'aotus',
    'ape',
    'aphid',
    'armadillo',
    'asp',
    'avocet',
    'ayu',
    'baboon',
    'badger',
    'balinese',
    'bandicoot',
    'barbel',
    'barnacle',
    'barracuda',
    'basilisk',
    'bat',
    'beagle',
    'bear',
    'beaver',
    'bedbug',
    'bee',
    'beetle',
    'bengal',
    'betta',
    'bird',
    'birman',
    'bison',
    'blackbird',
    'blowfish',
    'bluebird',
    'boa',
    'boar',
    'bobcat',
    'bobolink',
    'bobtail',
    'bocaccio',
    'boiga',
    'bombay',
    'bonobo',
    'booby',
    'boomslang',
    'borzoi',
    'bovid',
    'boxer',
    'budgie',
    'burbot',
    'burmese',
    'butterfly',
    'buzzard',
    'calico',
    'camel',
    'canary',
    'canid',
    'canidae',
    'capuchin',
    'capybara',
    'cardinal',
    'caribou',
    'carp',
    'cat',
    'caterpillar',
    'catfish',
    'catshark',
    'cattle',
    'centipede',
    'cephalopod',
    'chameleon',
    'cheetah',
    'chick',
    'chickadee',
    'chicken',
    'chimpanzee',
    'chinchilla',
    'chipmunk',
    'cicada',
    'clam',
    'clownfish',
    'cobra',
    'cockatiel',
    'cockatoo',
    'cockroach',
    'cod',
    'collie',
    'condor',
    'constrictor',
    'coot',
    'copperhead',
    'coral',
    'corgie',
    'cornsnake',
    'cougar',
    'covey',
    'cow',
    'coyote',
    'crab',
    'crane',
    'crawdad',
    'crayfish',
    'crocodile',
    'crow',
    'cuckoo',
    'dachshund',
    'damselfly',
    'darter',
    'deer',
    'diamondback',
    'dingo',
    'dinosaur',
    'dog',
    'dolphin',
    'donkey',
    'dormouse',
    'dove',
    'dragon',
    'dragonfly',
    'duck',
    'eagle',
    'earthworm',
    'earwig',
    'echidna',
    'eel',
    'egret',
    'elephant',
    'elk',
    'emu',
    'ermine',
    'falcon',
    'feist',
    'felidae',
    'ferret',
    'finch',
    'firefly',
    'fishes',
    'flamingo',
    'flea',
    'flounder',
    'fly',
    'flyingfish',
    'fowl',
    'fox',
    'frog',
    'galliform',
    'gamefowl',
    'gayal',
    'gazelle',
    'gecko',
    'gelada',
    'gerbil',
    'gibbon',
    'giraffe',
    'goat',
    'goldfinch',
    'goldfish',
    'goose',
    'gopher',
    'gorilla',
    'grasshopper',
    'grouper',
    'grouse',
    'guan',
    'guanaco',
    'guineafowl',
    'gull',
    'guppy',
    'haddock',
    'halibut',
    'hamster',
    'hare',
    'harrier',
    'hawk',
    'hedgehog',
    'heron',
    'herring',
    'himalayan',
    'hippopotamus',
    'hognose',
    'hookworm',
    'hornet',
    'horse',
    'hound',
    'hoverfly',
    'howler',
    'hummingbird',
    'husky',
    'hyena',
    'iguana',
    'impala',
    'indri',
    'jackal',
    'jackdaw',
    'jaguar',
    'javanese',
    'jay',
    'jellyfish',
    'junglefowl',
    'kangaroo',
    'kestrel',
    'kingfisher',
    'kite',
    'kiwibird',
    'koala',
    'koi',
    'korat',
    'krait',
    'krill',
    'ladybug',
    'lamprey',
    'lancehead',
    'landfowl',
    'langur',
    'lark',
    'leech',
    'lemming',
    'lemur',
    'leopard',
    'leopon',
    'limpet',
    'lion',
    'lizard',
    'llama',
    'lobster',
    'locust',
    'longhair',
    'loon',
    'loris',
    'louse',
    'lungfish',
    'lynx',
    'macaque',
    'macaw',
    'mackerel',
    'magpie',
    'maltese',
    'mamba',
    'mammal',
    'manatee',
    'mandrill',
    'marlin',
    'marmalade',
    'marmoset',
    'marmot',
    'marsupial',
    'marten',
    'martin',
    'mastodon',
    'meadowlark',
    'meerkat',
    'mink',
    'minnow',
    'mite',
    'mockingbird',
    'mole',
    'mollusk',
    'mongoose',
    'monkey',
    'moose',
    'mosquito',
    'moth',
    'mouse',
    'mule',
    'mullet',
    'muskox',
    'narwhal',
    'newt',
    'nightingale',
    'ocelot',
    'octopus',
    'opossum',
    'orangutan',
    'orca',
    'oriental',
    'osprey',
    'ostrich',
    'otter',
    'owl',
    'ox',
    'panda',
    'panther',
    'parakeet',
    'parrot',
    'parrotfish',
    'partridge',
    'peacock',
    'peafowl',
    'pelican',
    'penguin',
    'perch',
    'persian',
    'pheasant',
    'pig',
    'pigeon',
    'pike',
    'pinniped',
    'pinscher',
    'pintail',
    'piranha',
    'planarian',
    'platypus',
    'pollock',
    'pony',
    'poodle',
    'porcupine',
    'porpoise',
    'possum',
    'prawn',
    'primate',
    'ptarmigan',
    'puffin',
    'pug',
    'puma',
    'pythons',
    'quail',
    'quelea',
    'quetzal',
    'quokka',
    'rabbit',
    'raccoon',
    'rail',
    'rat',
    'rattlesnake',
    'raven',
    'razorbill',
    'reindeer',
    'retriever',
    'rhea',
    'rhinoceros',
    'roadrunner',
    'rodent',
    'rook',
    'rooster',
    'rottweiler',
    'roundworm',
    'sailfish',
    'salamander',
    'salmon',
    'sardine',
    'sawfish',
    'scallop',
    'schnauzer',
    'scorpion',
    'seahorse',
    'setter',
    'shark',
    'sheep',
    'shepherd',
    'shrew',
    'shrike',
    'shrimp',
    'siamese',
    'siberian',
    'silkworm',
    'silverfish',
    'skink',
    'skunk',
    'skylark',
    'sloth',
    'slug',
    'smelt',
    'snail',
    'snake',
    'snapper',
    'snipe',
    'sole',
    'spaniel',
    'sparrow',
    'spider',
    'spitz',
    'spoonbill',
    'squid',
    'squirrel',
    'starfish',
    'starling',
    'stingray',
    'stoat',
    'stork',
    'sturgeon',
    'swallow',
    'swan',
    'swift',
    'swordfish',
    'swordtail',
    'tabby',
    'tahr',
    'takin',
    'tamarin',
    'tanager',
    'tapir',
    'tarantula',
    'tarsier',
    'termite',
    'tern',
    'terrier',
    'thrush',
    'tick',
    'tiger',
    'tiglon',
    'tilapia',
    'toad',
    'tom',
    'tortoise',
    'toucan',
    'trout',
    'tuna',
    'turkeys',
    'turtle',
    'tyrannosaurus',
    'unicorn',
    'urial',
    'vicuna',
    'viper',
    'vole',
    'vulture',
    'wallaby',
    'walrus',
    'warbler',
    'wasp',
    'weasel',
    'westie',
    'whale',
    'whippet',
    'whitefish',
    'wildcat',
    'wildebeest',
    'wildfowl',
    'wolf',
    'wolverine',
    'wombat',
    'woodpecker',
    'worm',
    'wren',
    'yak',
    'zebra',

]



PLANTS = [
    'acacia',
    'acorn',
    'agave',
    'alfalfa',
    'aloevera',
    'apple',
    'apricot',
    'ash',
    'aster',
    'avocado',
    'azalea',
    'bamboo',
    'banana',
    'bark',
    'basil',
    'bean',
    'begonia',
    'berry',
    'birch',
    'blade',
    'bleedingheart',
    'bluebell',
    'bonsai',
    'bougainvillea',
    'brush',
    'bud',
    'bulb',
    'bush',
    'cactus',
    'camellia',
    'cantaloupe',
    'carnation',
    'catnip',
    'cedar',
    'celosia',
    'chamomile',
    'cherry',
    'chrysanthemum',
    'citron',
    'citrus',
    'clematis',
    'clover',
    'coconut',
    'coralbells',
    'coreopsis',
    'cork',
    'corolla',
    'cosmos',
    'crocus',
    'cyclamen',
    'daffodil',
    'dahlia',
    'daisy',
    'dandelion',
    'delphinium',
    'echinacea',
    'elderberry',
    'fennel',
    'fern',
    'ficus',
    'fig',
    'flora',
    'forsythia',
    'foxglove',
    'freesia',
    'fruit',
    'garden',
    'gardenia',
    'geranium',
    'gladiolus',
    'goldenrod',
    'grain',
    'grape',
    'grass',
    'grove',
    'guava',
    'hellebore',
    'herb',
    'hibiscus',
    'holly',
    'honeysuckle',
    'hosta',
    'hyacinth',
    'hydrangea',
    'iris',
    'ivy',
    'jasmine',
    'juniper',
    'kelp',
    'kiwi',
    'kudzu',
    'lantana',
    'lavender',
    'lemon',
    'lilac',
    'lily',
    'lime',
    'lupin',
    'lupine',
    'magnolia',
    'mango',
    'maple',
    'marigold',
    'melon',
    'moss',
    'mulberry',
    'narcissus',
    'nasturtium',
    'nectar',
    'nectarine',
    'oak',
    'orange',
    'orchid',
    'palm',
    'pansy',
    'papaya',
    'peach',
    'pear',
    'peony',
    'petal',
    'petunia',
    'pine',
    'pineapple',
    'plum',
    'poinsettia',
    'poppy',
    'primrose',
    'prune',
    'quince',
    'raisin',
    'raspberry',
    'resin',
    'rhododendron',
    'rose',
    'rosemary',
    'rudbeckia',
    'sage',
    'salvia',
    'sedum',
    'shrub',
    'snapdragon',
    'snowdrop',
    'spiderplant',
    'spine',
    'sprout',
    'spruce',
    'stalk',
    'sunflower',
    'tangerine',
    'thorn',
    'thyme',
    'tree',
    'tulip',
    'twig',
    'vein',
    'vine',
    'violet',
    'weed',
    'wisteria',
    'yarrow',
    'yew',
    'yucca',
    'zinnia',

]
